@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: icontroladorextensiones.h 3500 2011-03-14 19:41:29Z tovar $
+ *  $Id: icontroladorextensiones.h 3808 2011-04-29 11:12:01Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -19,8 +19,7 @@
 #include "icontroladormodulo.h"
 #include "observers/iextensionsobserver.h"
 
-#include <prvext/prvext.h>
-
+class PrivateExtension;
 class wxDynamicLibrary;
 
 namespace GADVAPI {
