@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: initwx.cpp 3910 2011-07-01 10:12:00Z tovar $
+ *  $Id: initwx.cpp 4188 2011-09-23 08:13:40Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -261,16 +261,38 @@ bool Ginkgo::OnInit()
 		{
 			wxFileName fileName;
 			if (argc == 2) {
-				fileName = wxFileName(wxString(argv[1]));
+				fileName = wxFileName(argv[1]);
+				if (fileName.IsRelative()) {
+					#if defined(__WXGTK__)
+					char* invocation_dir = getenv("INVOCATION_DIR");					
+					if (invocation_dir != NULL) {
+						wxString invocationDir = wxString::FromUTF8(invocation_dir);
+						if (!invocationDir.IsEmpty()) {
+							fileName = invocationDir + wxFileName::GetPathSeparator() + fileName.GetFullPath();
+						}
+					}					
+					#else
+					fileName.MakeAbsolute();
+					#endif
+				}			
+				if (fileName.IsOk() && ((fileName.FileExists() && fileName.IsFileReadable()) || (wxDirExists(fileName.GetFullPath()) && fileName.IsDirReadable()))) {
+					LOG_INFO("Core", "The client sends following file: " << fileName.GetFullPath().ToUTF8());
+					// Ask the other instance to open a file or raise itself
+					connection->Execute(fileName.GetFullPath());
+					connection->Disconnect();
+					delete connection;
+				}
+				else {
+					wxString err = wxString::Format(wxT("Error: The file %s does not exists or is not readable"), argv[1]);
+					LOG_ERROR("Core", TOPATH(err));
+					wxMessageBox(err, wxT("Ginkgo CADx"), wxICON_INFORMATION|wxOK);
+				}			
+			} else {
+				// Ask the other instance to open a file or raise itself
+				connection->Execute(wxT(""));
+				connection->Disconnect();
+				delete connection;
 			}
-			if (fileName.IsRelative()) {
-				fileName.MakeAbsolute();
-			}
-			LOG_INFO("Core", "The client sends following file: " << fileName.GetFullPath().ToUTF8());
-			// Ask the other instance to open a file or raise itself
-			connection->Execute(fileName.GetFullPath());
-			connection->Disconnect();
-			delete connection;
 		}
 		else
 		{
@@ -293,18 +315,23 @@ bool Ginkgo::OnInit()
 		GNC::GCS::ControladorInternacionalizacion::Instance()->AddCatalog("ginkgocadxcore");
 	}
 	//permisos del core
-	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.history", _Std("Anonymous medical history"), "anonymous", _Std("Anonymous mode (history is cleaned)"), false, "", false);
+	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.restrictions", _Std("Ginkgo CADx Restrictions"), "anonymous_history", _Std("Anonymous mode (history is cleaned)"), false, "", false);
+	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.restrictions", _Std("Ginkgo CADx Restrictions"), "max_tabs", _Std("Max number of tabs opened"), false, "2", false);
+	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.restrictions", _Std("Ginkgo CADx Restrictions"), "inactivity_time", _Std("Max seconds of Ginkgo CADx application inactivity"), false, "600", false);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.help", _Std("Online Manual"), "url_manual", _Std("URL of online manual"), true, "http://doc.ginkgo-cadx.com/", true);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.help", _Std("Online Support"), "url_support", _Std("URL of online support"), true, _Std("http://ginkgo-cadx.com/en/services/"), true);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.help", _Std("Extensions Support"), "extensions_support", _Std("URL for new extensions"), true, _Std("http://ginkgo-cadx.com/en/extensions/"), true);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.update", _Std("Program Updates"), "check_updates", _Std("Warn about newest Ginkgo CADx updates"), false, "http://updates.ginkgo-cadx.com/version.xml", true);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.update", _Std("Program Updates"), "update_period", _Std("Update period (days)"), false, "2", true);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.seguridad",_Std("Security"), "setup_security", _Std("Setup Security"), false, "", false);
-	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.adquisicion",_Std("Acquisition"), "pacs", _Std("Acquire images from PACS"),false, "", true);
-	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.menu",_Std("Tools"),"subir pacs",_Std("Upload images to a PACS server"), false, "", true);
+	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.startup", _Std("Show on startup"), "startupdefaultvalue", _Std("Show on startup default value"), true, "", true);
+	
+	
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.menu",_Std("Tools"),"configuracion",_Std("Settings menu"), false, "", true);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.menu",_Std("Tools"),"filtrado",_Std("Filter menu"), true, "", false);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.menu",_Std("Tools"),"licencia",_Std("License menu"), true, "", true);
+	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.pacs.limits", _Std("PACS Limits"),"pacs_upload",_Std("Upload images to a PACS server"), false, "", true);
+	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.pacs.limits", _Std("PACS Limits"), "pacs_acquisition", _Std("Acquire images from PACS"),false, "", true);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.pacs.limits", _Std("PACS Limits"), "remote_pacs", _Std("Enable remote PACS configuration"), false, "", true);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.pacs.limits", _Std("PACS Limits"), "pacs_tls", _Std("Enable TLS configuration"), false, "", true);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.pacs.limits", _Std("PACS Limits"), "patient_scope", _Std("Restrict search over selected patient"), false, "", false);
@@ -325,6 +352,9 @@ bool Ginkgo::OnInit()
 		wxString texto = wxString::Format(_("Download %s images"),wxString::FromUTF8(modalidades[i].c_str()).c_str());
 		GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.pacs.download",_Std("PACS"),modalidades[i],std::string(texto.ToUTF8()),false, "", true);
 	}
+		
+	wxString texto = _("Download all modalities");
+	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.pacs.download",_Std("PACS"),"all",std::string(texto.ToUTF8()),false, "", true);
 
 	//
 
@@ -427,6 +457,7 @@ bool Ginkgo::OnInit()
 			cH->RegistrarHerramienta(new GNC::HerramientaPanelTags());
 			cH->RegistrarHerramienta(new GNC::HerramientaDesencajar());
 			cH->RegistrarHerramienta(new GNC::HerramientaDeshacer());
+			cH->RegistrarHerramienta(new GNC::HerramientaInterpolate());
 			
 
 			//especial
@@ -538,6 +569,7 @@ int Ginkgo::OnExit()
 	GNC::GCS::IHerramientaLayoutVentana*    hLayoutVentana  = NULL;
 	GNC::GCS::IHerramientaDesencajar*		hDesencajar = NULL;
 	GNC::GCS::IHerramientaDeshacer*		hDeshacer = NULL;
+	GNC::GCS::IHerramientaInterpolate* hInterpolate = NULL;
 
 	try {
 		hPuntero = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaPuntero>(GNC::GCS::IHerramientaPuntero::ID);
@@ -624,13 +656,21 @@ int Ginkgo::OnExit()
 			cH->DesRegistrarHerramienta(hDeshacer);
 			delete hDeshacer;
 		}
+
+		hInterpolate = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaInterpolate>(GNC::GCS::IHerramientaInterpolate::ID);
+		if (hInterpolate != NULL) {
+			cH->DesRegistrarHerramienta(hInterpolate);
+			delete hInterpolate;
+		}
 	}
 	catch (GNC::GCS::ControladorHerramientasException& ex) {
 		std::cerr << "Error al registrar herramientas de Derma: No se pudo subscribir la herramienta: " << ex.getCause() << std::endl;
 	}
 
 
+	GNC::GCS::ControladorVistas::FreeInstance();
 	GIL::XMLRPC::XMLRPCController::FreeInstance();
+	GIL::HL7::ControladorEnvioHl7::FreeInstance();
 	GNC::GCS::ControladorAcciones::FreeInstance();
 	GNC::GCS::ControladorComandos::FreeInstance();
 	GIL::DICOM::PACSController::FreeInstance();
@@ -639,7 +679,6 @@ int Ginkgo::OnExit()
 	GNC::GCS::ControladorCarga::FreeInstance();
 	GNC::ControladorHerramientas::FreeInstance();
 	GNC::GCS::ControladorHistorial::FreeInstance();
-	GIL::HL7::ControladorEnvioHl7::FreeInstance();
 	GIL::HL7::ControladorBBDDHl7::FreeInstance();
 	GNC::GCS::ControladorPermisos::FreeInstance();
 	GNC::GCS::ControladorInternacionalizacion::FreeInstance();
@@ -694,12 +733,21 @@ void Ginkgo::WriteHeaderLog(){
 	wxString date;
 
 	version << versionNumber;
-	versionNumber = GINKGO_SUB_VERSION;
 	version << ".";
+
+	versionNumber = GINKGO_SUB_VERSION;
 	version << versionNumber;
 	version << ".";
+
 	versionNumber = GINKGO_SUB_RELEASE;
 	version << versionNumber;
+	version << ".";
+
+	versionNumber = GINKGO_BUILD;
+	version << versionNumber;
+	version << " ";
+
+	version << GINKGO_CODENAME;
 
 	date=now.Format(wxT("%d/%m/%Y %H:%M:%S"),wxDateTime::CET);
 
