@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: comandoavisarficheros.h 3521 2011-03-16 14:54:22Z carlos $
+*  $Id: comandoavisarficheros.h 3839 2011-05-11 08:47:59Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -25,9 +25,10 @@ namespace GADAPI {
 	public:
 		typedef std::list<std::string> TipoListaFicheros;
 
-		ComandoAvisarFicherosParams(const TipoListaFicheros& listaFicheros);
+		ComandoAvisarFicherosParams(const TipoListaFicheros& listaFicheros, bool openAfter = false);
 
 		TipoListaFicheros m_listaFicheros;
+		bool m_openAfter;
 	};
 
 	class EXTAPI ComandoAvisarFicheros : public GNC::GCS::IComando {
