@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: comandocarga.cpp 3921 2011-07-06 11:36:02Z tovar $
+*  $Id: comandocarga.cpp 4158 2011-09-19 13:25:20Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -31,13 +31,14 @@
 
 #define IDC_CARGA       91
 
-GADAPI::ComandoCargaParams::ComandoCargaParams(GNC::GCS::IVista* pVista, GnkPtr<GIL::IModeloIntegracion>& modeloIntegracion, const std::string& uidEstudioDiagnostico)
+GADAPI::ComandoCargaParams::ComandoCargaParams(GNC::GCS::IVista* pVista, GnkPtr<GIL::IModeloIntegracion>& modeloIntegracion, const std::string& uidEstudioDiagnostico, const bool loadFirst)
 {
 	IVista = pVista;
 	ModeloIntegracion = modeloIntegracion;
 	UIDEstudioDiagnostico = uidEstudioDiagnostico;
 	Padre = NULL;
 	GNC::Entorno* pEntorno = GNC::Entorno::Instance();
+	LoadFirst = loadFirst;
 	pEntorno->ObservadoresVistas.push_back(this);
 }
 
@@ -82,11 +83,14 @@ void GADAPI::ComandoCarga::Execute()
 		try {
 			//se le da la oportunidad a la vista de que haga cosas asincronas con la interfaz, por ejemplo reordenar ficheros
 			CargaParams->IVista->CargarEstudio(this);
-			GnkPtr<GNC::GCS::IContextoEstudio> estudio = CargaParams->IVista->GetEstudio();
-			if (!estudio->GetRutasImagenes().empty()) {
-				estudio->Loader->SetInput(estudio->GetRutasImagenes()[0]);
-			} else {
-				Error = _Std("Series path couldn't be found");
+			if (CargaParams->LoadFirst) {
+				GnkPtr<GNC::GCS::IContextoEstudio> estudio = CargaParams->IVista->GetEstudio();
+				
+				if (!estudio->GetRutasImagenes().empty()) {
+					estudio->Loader->SetInput(estudio->GetRutasImagenes()[0]);
+				} else {
+					Error = _Std("Series path couldn't be found");
+				}
 			}
 		}
 		catch( GNC::GCS::VistaException& ex )
