@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: controladorherramientas.cpp 3830 2011-05-06 13:30:18Z carlos $
+ *  $Id: controladorherramientas.cpp 4124 2011-09-02 12:21:20Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -87,11 +87,61 @@ public:
 		m_pControlador->OnActivarHerramienta(event);
 	}
 
-
 	GNC::ControladorHerramientas* m_pControlador;
 
 };
 
+namespace GNC {
+	namespace GUI {
+		class EventHandlerKeyToolsController: public wxEvtHandler {
+		public:
+			EventHandlerKeyToolsController(GNC::ControladorHerramientas* pController): wxEvtHandler()
+			{
+				m_pController = pController;
+				m_pParent = NULL;
+			}
+			~EventHandlerKeyToolsController() 
+			{
+				Disconnect();
+			}
+
+			void OnKeyEvent(wxKeyEvent& event) {
+				//tools accelerators are ctrl + keycode
+				if (event.ControlDown() && event.GetKeyCode() != WXK_CONTROL) {
+					m_pController->OnKeyAccelerator(event);
+					#if defined(__WXGTK__)
+					if (m_pParent != NULL) {
+						m_pParent->SetFocus();
+					}
+					#endif
+				} else {
+					event.ResumePropagation(1);
+					event.Skip(true);
+				}
+				
+			}
+
+			void Connect(wxWindow* pParent) {
+				if (m_pParent != NULL) {
+					m_pParent->Disconnect(wxEVT_KEY_DOWN, wxKeyEventHandler( EventHandlerKeyToolsController::OnKeyEvent ), NULL, this);
+				}
+				m_pParent = pParent;
+				m_pParent->Connect(wxEVT_KEY_DOWN, wxKeyEventHandler( EventHandlerKeyToolsController::OnKeyEvent ), NULL, this);
+			}
+
+			void Disconnect() {
+				if (m_pParent != NULL) {
+					m_pParent->Disconnect(wxEVT_KEY_DOWN, wxKeyEventHandler( EventHandlerKeyToolsController::OnKeyEvent ), NULL, this);
+					m_pParent = NULL;
+				}
+			}
+
+			GNC::ControladorHerramientas* m_pController;
+			wxWindow* m_pParent;
+		};
+	}
+}
+
 GNC::ControladorHerramientas::ControladorHerramientas()
 {
 	m_pVistaActiva = NULL;
@@ -121,6 +171,8 @@ GNC::ControladorHerramientas::ControladorHerramientas()
 
 	m_pBarraHerramientasDerecha = new GNC::GUI::BarraHerramientasDerecha(pEntorno->GetPanelHerramientasSuperior(), pEntorno->GetVentanaPrincipal());
 	pEntorno->GetPanelHerramientasSuperior()->GetSizer()->Add( m_pBarraHerramientasDerecha, 0, wxEXPAND, 0 );
+
+	m_pKeyEventHandler = new GNC::GUI::EventHandlerKeyToolsController(this);
 }
 
 GNC::ControladorHerramientas::~ControladorHerramientas()
@@ -152,6 +204,11 @@ GNC::ControladorHerramientas::~ControladorHerramientas()
 	}
 	m_Herramientas.clear();
 	m_MapaIdsHerramientas.clear();
+
+	if (m_pKeyEventHandler != NULL)
+	{
+		delete m_pKeyEventHandler;
+	}
 }
 
 GNC::ControladorHerramientas* GNC::ControladorHerramientas::Instance()
@@ -590,6 +647,10 @@ void GNC::ControladorHerramientas::OnVistaActivada(GNC::GCS::IVista* pVista)
 		std::cout << "  ANT: VistaActiva = " << pVista->GetTitulo().c_str() << ", ModuloActivo = " << m_pModuloActivo->GetNombre().c_str() << std::endl;
 		#endif
 
+		//disconnect key events...
+		m_pKeyEventHandler->Disconnect();
+		//
+
 		GNC::GCS::IHerramienta* pH = m_HerramientaActiva[m_pModuloActivo];
 		if (pH != NULL) {
 			pH->SetVistaActiva(pVista);
@@ -632,6 +693,10 @@ void GNC::ControladorHerramientas::OnVistaActivada(GNC::GCS::IVista* pVista)
 	m_pVistaActiva = pVista;
 	if(m_pVistaActiva !=NULL){
 		m_pModuloActivo = m_pVistaActiva->GetModulo();
+
+		//connect key events
+		m_pKeyEventHandler->Connect(m_pVistaActiva->GetWindow());
+		//
 	}else{
 		m_pModuloActivo = NULL;
 	}
@@ -756,6 +821,8 @@ void GNC::ControladorHerramientas::SolicitarActivacion(GNC::GCS::IHerramienta* h
 		}
 		herramienta->Conectar(true);
 
+		GNC::GCS::ControladorVistas::Instance()->GetVistaActiva()->Activar();
+
 		m_HerramientaActiva[m_pModuloActivo] = herramienta;
 	}
 
@@ -784,6 +851,23 @@ void GNC::ControladorHerramientas::OnActivarHerramienta(wxCommandEvent& event)
 	}
 }
 
+void GNC::ControladorHerramientas::OnKeyAccelerator(wxKeyEvent& event)
+{
+	//find tool with accelerator = event.GetKeyCode()
+	int keyCode = event.GetKeyCode();
+	for (MapaHerramientas::iterator it = m_Herramientas.begin(); it != m_Herramientas.end(); it++) {
+		GNC::GCS::IHerramienta* pHerramienta = (*it).second;
+
+		if (pHerramienta != NULL) {
+			if (pHerramienta->Habilitada() && !pHerramienta->Activada() && pHerramienta->GetAcceleratorCode() == keyCode) {
+				SolicitarActivacion(pHerramienta);
+				event.Skip(false);				
+				break;
+			}
+		}
+	}
+}
+
 // </editor-fold>
 //endregion
 
