@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: controladorhl7.cpp 3963 2011-07-11 14:03:51Z tovar $
+ *  $Id: controladorhl7.cpp 4034 2011-07-21 09:44:05Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -56,7 +56,7 @@ GIL::HL7::ControladorHL7::ControladorHL7(TipoInterpretacion interpretacion, Tipo
 	GnkPtr<GIL::HL7::IXMLIntegrationParser> english(new GIL::HL7::ParserXMLEnglish());
 	keys = english->GetKeys();
 	for (std::list<std::string>::iterator it = keys.begin(); it != keys.end(); ++it) {
-		RegisterParser((*it), spanish);
+		RegisterParser((*it), english);
 	}
 }
 
@@ -205,6 +205,21 @@ std::string GIL::HL7::ControladorHL7::GetUIDModulo(const std::string& idPlantill
 	return sidModulo;
 }
 
+std::string GIL::HL7::ControladorHL7::GetIdPlantilla(const std::string& uidModulo) const
+{
+	GNC::GCS::IControladorModulo* pModuleController = GNC::ControladorExtensiones::Instance()->ObtenerModulo(uidModulo);
+	if (pModuleController == NULL) {
+		std::ostringstream os;
+		os << _Std("Unknown module Id (") << uidModulo.c_str();
+		throw HL7Exception(os.str(),"PID");
+	}
+
+	std::string entradaConf = "TUID" + pModuleController->GetUID();
+	std::string templateId;
+	GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/HCE/Plantillas", entradaConf, templateId);
+	return templateId;
+}
+
 
 void GIL::HL7::ControladorHL7::ConstruirMensajeDeEvidencias(GIL::HL7::Message& msg, const GIL::IModeloIntegracion* const modelo) const
 {
@@ -253,7 +268,7 @@ void GIL::HL7::ControladorHL7::ConstruirMensajeDeEvidencias(GIL::HL7::Message& m
 		GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/Estacion","CentroNombre",nombreCentroLocal);
 		GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/Estacion","CentroId",idCentroLocal);
 		
-		{
+		if (modelo->UIDModulo == "") {
 			std::stringstream ss;
 
 			std::string uidModulo = GetUIDModulo(modelo->idPlantilla);
@@ -261,6 +276,10 @@ void GIL::HL7::ControladorHL7::ConstruirMensajeDeEvidencias(GIL::HL7::Message& m
 
 			processingId = ss.str();
 		}
+		std::string templateId = modelo->idPlantilla;
+		if (templateId == "") {
+			templateId = GetIdPlantilla(modelo->UIDModulo);
+		}
 
 		{
 			std::string aetLocal = GNC::Entorno::Instance()->GetDicomLocalAET();
@@ -365,7 +384,7 @@ void GIL::HL7::ControladorHL7::ConstruirMensajeDeEvidencias(GIL::HL7::Message& m
 						order.observationRequest.SetLateralityLeft();
 					}*/
 
-					order.observationRequest.SetIdentifier(modelo->idPlantilla);
+					order.observationRequest.SetIdentifier(templateId);
 					order.observationRequest.SetPlacerField1(evidenciaEstudio.AccessionNumber);
 
 
