@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: dicomechoassociation.h 3526 2011-03-16 19:56:19Z carlos $
+ *  $Id: dicomechoassociation.h 3834 2011-05-10 07:42:57Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -13,7 +13,7 @@
  */
 #pragma once
 #include "dicomassociation.h"
-#include <api/imodelodicom.h>
+#include <api/dicom/imodelodicom.h>
 
 class EchoAssociation : public Association {
 public:
