@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: dicomservers.cpp 3893 2011-06-21 13:01:56Z tovar $
+ *  $Id: dicomservers.cpp 4103 2011-08-31 06:33:25Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -188,7 +188,8 @@ DicomServer* DicomServerList::GetLast()
 	return &lastInsertedHolder->server;
 }
 
-void DicomServerList::Reload(){
+void DicomServerList::Reload()
+{
 	DicomServerHolder* holder = NULL;
 	DicomServerHolder* tempHolder = NULL;
 	for (holder = serverHolders; holder != NULL;) {
@@ -197,6 +198,10 @@ void DicomServerList::Reload(){
 		delete holder;
 		holder = tempHolder;
 	}
+	if (localServer != NULL) {
+		delete localServer;
+		localServer = NULL;
+	}
 	serverHolders = NULL;
 	lastInsertedHolder = NULL;
 
