@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: pacscontroller.cpp 3897 2011-06-22 10:15:17Z tovar $
+*  $Id: pacscontroller.cpp 4103 2011-08-31 06:33:25Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -526,12 +526,13 @@ namespace GIL {
 										FileRecord->findAndGetOFString(DCM_ReferencedSOPInstanceUIDInFile, uidImagen);
 
 										wxString wxStr = FROMPATH(tmpString);
-										wxChar separador = wxFileName::GetPathSeparator();
-										wxChar barra = wxT('\\');
-										wxStr.Replace(&barra,&separador);
+										wxString separador = wxFileName::GetPathSeparator();
+										wxString barra = wxT('\\');
+										wxStr.Replace(barra,separador);
 										std::ostringstream ostr;
 										tmpString = TOPATH(wxStr);
-										ostr << basePath << (char)separador << tmpString;
+										ostr << basePath << separador.ToUTF8();
+										ostr << tmpString;
 
 										pModelo->InsertarImagen(uidSerie.c_str(),uidImagen.c_str(),ostr.str());
 									}
