@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: entorno.cpp 3986 2011-07-13 13:34:37Z tovar $
+ *  $Id: entorno.cpp 4024 2011-07-20 08:36:15Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -174,11 +174,15 @@ GNC::Entorno::Entorno()
 	GNC::GCS::ConfigurationController::Instance()->readGroupGeneral("/GinkgoCore/Locations", locations);
 	for (GNC::GCS::ConfigurationController::TListGroups::iterator it = locations.begin(); it != locations.end(); it++) {
 		std::string title, path, descr;
+		bool monitorize, cleanbefore, cleanafter;
 		(*it).readStringValue("Title", title);
 		(*it).readStringValue("Path", path);
 		(*it).readStringValue("Description", descr);
+		(*it).readBoolValue("Monitorize", monitorize, false);
+		(*it).readBoolValue("CleanBefore", cleanbefore, false);
+		(*it).readBoolValue("CleanAfter", cleanafter, false);
 
-		m_Ubicaciones[title] = GIL::Ubicacion(title, path, descr);
+		m_Ubicaciones[title] = GIL::Ubicacion(title, path, descr, monitorize, cleanbefore, cleanafter);
 	}
 
 	// Refrescar Dicom dir
