@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: panelconfiguraciongeneral.cpp 3896 2011-06-22 07:08:49Z tovar $
+ *  $Id: panelconfiguraciongeneral.cpp 4167 2011-09-21 08:52:31Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -79,7 +79,7 @@ namespace GNC {
 			
 			//internacionalizacion
 			int language;
-			GNC::GCS::ConfigurationController::Instance()->readIntUser("/GinkgoCore/Station", "Language", language, true);
+			GNC::GCS::ConfigurationController::Instance()->readIntUser("/GinkgoCore/Station", "Language", language);
 
 			//explore lang directory to find installed languages
 			{
