@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: panelestudio.cpp 3907 2011-07-01 07:27:36Z tovar $
+ *  $Id: panelestudio.cpp 4044 2011-07-22 12:21:07Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -127,7 +127,7 @@ namespace GNC {
 			menu.Connect(5,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelEstudio::OnAbrir),NULL,this);
 			menu.Append(5, wxT("Abrir Serie con.."));
 			menu.Connect(5,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelHistorial::OnAbrirCon),NULL,this);*/
-			if(GNC::GCS::ControladorPermisos::Instance()->Get("core.menu","subir pacs")) {
+			if(GNC::GCS::ControladorPermisos::Instance()->Get("core.pacs.limits","pacs_upload")) {
 				wxMenuItem* pMenuSend = new wxMenuItem(&menu, 7, wxString( _("Send to PACS server") ), _("Send to PACS server"), wxITEM_NORMAL );
 				menu.Connect(7,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelEstudio::OnUploadPACS),NULL,this);
 				#ifdef __WXMSW__
