@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: panelhistorial2.cpp 3933 2011-07-07 07:40:00Z tovar $
+ *  $Id: panelhistorial2.cpp 4044 2011-07-22 12:21:07Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -160,7 +160,7 @@ namespace GNC {
 			}
 
 			//si es preciso limpiar historial...
-			GNC::GCS::Permisos::EstadoPermiso estado = GNC::GCS::ControladorPermisos::Instance()->Get("core.history", "anonymous");
+			GNC::GCS::Permisos::EstadoPermiso estado = GNC::GCS::ControladorPermisos::Instance()->Get("core.restrictions", "anonymous_history");
 			if (estado) {
 				GNC::GCS::ControladorHistorial::Instance()->VaciarHistorial(true);
 			}
@@ -174,7 +174,7 @@ namespace GNC {
 		{
 			if (comprobarPurga) {
 				//si es preciso limpiar historial...
-				GNC::GCS::Permisos::EstadoPermiso estado = GNC::GCS::ControladorPermisos::Instance()->Get("core.history", "anonymous");
+				GNC::GCS::Permisos::EstadoPermiso estado = GNC::GCS::ControladorPermisos::Instance()->Get("core.restrictions", "anonymous_history");
 				if (estado) {
 					GNC::GCS::ControladorHistorial::Instance()->VaciarHistorial(true);
 				}
@@ -958,14 +958,14 @@ namespace GNC {
 
 			menu.Append(pMenuOpenFile);
 			menu.Append(pMenuOpenFolder);
-			if(GNC::GCS::ControladorPermisos::Instance()->Get("core.adquisicion","pacs")) {
+			if(GNC::GCS::ControladorPermisos::Instance()->Get("core.pacs.limits","pacs_acquisition")) {
 				menu.AppendSeparator();
 				menu.Append( pMenuAdquirir );
 			} else {
 				delete pMenuAdquirir;
 			}
 			menu.AppendSeparator();
-			if(GNC::GCS::ControladorPermisos::Instance()->Get("core.menu","subir pacs")) {
+			if(GNC::GCS::ControladorPermisos::Instance()->Get("core.pacs.limits","pacs_upload")) {
 				menu.Append(pMenuSend);
 			} else {
 				delete pMenuSend;
