@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: panelpaciente.cpp 3933 2011-07-07 07:40:00Z tovar $
+ *  $Id: panelpaciente.cpp 4044 2011-07-22 12:21:07Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -237,14 +237,14 @@ namespace GNC {
 
 			menu.Append(pMenuOpenFile);
 			menu.Append(pMenuOpenFolder);
-			if(GNC::GCS::ControladorPermisos::Instance()->Get("core.adquisicion","pacs")) {
+			if(GNC::GCS::ControladorPermisos::Instance()->Get("core.pacs.limits","pacs_acquisition")) {
 				menu.AppendSeparator();
 				menu.Append( pMenuAdquirir );
 			} else {
 				delete pMenuAdquirir;
 			}
 			menu.AppendSeparator();
-			if(GNC::GCS::ControladorPermisos::Instance()->Get("core.menu","subir pacs")) {
+			if(GNC::GCS::ControladorPermisos::Instance()->Get("core.pacs.limits","pacs_upload")) {
 				menu.Append(pMenuSend);
 			} else {
 				delete pMenuSend;
