@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: panelserie.cpp 3985 2011-07-13 12:01:17Z tovar $
+ *  $Id: panelserie.cpp 4121 2011-09-02 10:30:20Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -25,6 +25,7 @@
 #include <main/controllers/controladoreventos.h>
 #include <main/controllers/controladorpermisos.h>
 #include <main/controllers/controladorhl7.h>
+#include <main/controllers/controladorenviohl7.h>
 #include <main/entorno.h>
 #include <main/gui/pacsupload/wxwizarduploadpacs.h>
 #include <commands/comandogenerarthumbnails.h>
@@ -320,7 +321,7 @@ namespace GNC {
 			}
 			//end reprocess		
 
-			if(GNC::GCS::ControladorPermisos::Instance()->Get("core.menu","subir pacs")) {
+			if(GNC::GCS::ControladorPermisos::Instance()->Get("core.pacs.limits","pacs_upload")) {
 				wxMenuItem* pMenuSend = new wxMenuItem(&menu, 7, wxString( _("Send to PACS server") ), _("Send to PACS server"), wxITEM_NORMAL );
 				menu.Connect(7,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelSerie::OnUploadPACS),NULL,this);
 				#ifdef __WXMSW__
@@ -442,6 +443,18 @@ namespace GNC {
 				}
 			}
 
+			//max number of opened tabs
+			GNC::GCS::Permisos::EstadoPermiso estado = GNC::GCS::ControladorPermisos::Instance()->Get("core.restrictions", "max_tabs");
+			if (estado) {
+				long maxNumberOfTabs = estado.ObtenerValor<long>();
+				if ((int)GNC::Entorno::Instance()->GetControladorVistas()->GetVistas().size() >= maxNumberOfTabs) {
+						wxMessageBox(_("You have reached maximum number of opened tabs, close some tabs and try it again"), _("Info"),
+							wxOK | wxICON_INFORMATION, GNC::Entorno::Instance()->GetVentanaRaiz());
+						return;					
+				}
+			}
+			//max
+
 			//darse cuenta si debe abrirse por estudios, en ese caso decirle al padre que se quiere abrir...
 			GNC::GCS::IControladorModulo* pModulo = NULL;
 			GNC::GCS::ModoControlador* pModo = NULL;
@@ -486,6 +499,18 @@ namespace GNC {
 
 		void PanelSerie::OnAbrirCon(wxCommandEvent& )
 		{
+			//max number of opened tabs
+			GNC::GCS::Permisos::EstadoPermiso estado = GNC::GCS::ControladorPermisos::Instance()->Get("core.restrictions", "max_tabs");
+			if (estado) {
+				long maxNumberOfTabs = estado.ObtenerValor<long>();
+				if ((int)GNC::Entorno::Instance()->GetControladorVistas()->GetVistas().size() >= maxNumberOfTabs) {
+						wxMessageBox(_("You have reached maximum number of opened tabs, close some tabs and try it again"), _("Info"),
+							wxOK | wxICON_INFORMATION, GNC::Entorno::Instance()->GetVentanaRaiz());
+						return;					
+				}
+			}
+			//max
+
 			DialogoAbrirCon::ListaModalidades listaModalidades;
 			listaModalidades.push_back(std::pair<std::string,std::string>(m_idModalidad, m_uidTransferSyntax));
 
@@ -596,6 +621,12 @@ namespace GNC {
 				return;
 			}
 
+			//restart hl7 sending service
+			if (!GIL::HL7::ControladorEnvioHl7::EstaArrancado()) {
+				GIL::HL7::ControladorEnvioHl7::Arrancar();
+			}
+			//
+
 			//darse cuenta si debe abrirse por estudios, en ese caso decirle al padre que se quiere abrir...
 			GNC::GCS::IControladorModulo* pModulo = NULL;
 
@@ -637,7 +668,16 @@ namespace GNC {
 						modelo->atendido = true;
 					if(modelo->accion == GIL::IModeloIntegracion::TA_Dicomizar) {
 						//se busca el dicomizador del modulo indicado, habra un mapa que transformara sid en uids de modulo
-						std::string uidModulo = controlador.GetUID(modelo->idPlantilla);
+						std::string uidModulo("");
+						if (modelo->idPlantilla != "") {
+							uidModulo = controlador.GetUID(modelo->idPlantilla);
+							modelo->UIDModulo = uidModulo;
+							if (GNC::ControladorExtensiones::Instance()->ObtenerModulo(uidModulo) == NULL) {
+								throw GIL::HL7::HL7Exception("No existe el modulo asociado", "Modelo", true);
+							}
+						} else {
+							uidModulo = pModulo->GetUID();
+						}
 						modelo->UIDModulo = uidModulo;
 						if (GNC::ControladorExtensiones::Instance()->ObtenerModulo(uidModulo) == NULL) {
 							throw GIL::HL7::HL7Exception("No existe el modulo asociado", "Modelo", true);
