@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: selectimagesimportation.h 3924 2011-07-06 15:11:05Z tovar $
+ *  $Id: selectimagesimportation.h 4056 2011-08-03 09:10:43Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -31,36 +31,52 @@ namespace GIL
 namespace GNC {
 	namespace GUI {
 		class ButtonsBar;
+		class TimerDirectory;
+		class DropTargetSelectImages;
 
 		class EXTAPI SelectImagesImportation: public SelectImagesImportationBase, public IPasoWizard
 		{
 			public:
-				SelectImagesImportation(wxWindow* pParent, std::string& dirTemp, IWizard* pWizard, bool reescalar, GnkPtr<GIL::IModeloIntegracion>& pModeloIntegracion, const std::list<std::string>& fileSpec = std::list<std::string>(), const wxString& defaultFilter = wxEmptyString);
+				SelectImagesImportation(wxWindow* pParent, std::string& dirTemp, IWizard* pWizard, GnkPtr<GIL::IModeloIntegracion>& pModeloIntegracion, const std::list<std::string>& fileSpec = std::list<std::string>(), const wxString& defaultFilter = wxEmptyString);
 				void SetDefaultImage(const wxImage& defaultImage);
 				~SelectImagesImportation();
 				
 				virtual void AddImages(const wxArrayString& files);
+				virtual bool ScanPath(const wxString& path);
 			
 			protected:
 				bool																			m_firstAttach;
 				std::string                                                 m_dirTemp;
-				bool                                                        m_reescalar;
 				GnkPtr<GIL::IModeloIntegracion>                             m_pModeloIntegracion;
 				ButtonsBar*																	m_pButtonsBar;
 				wxString																		m_pDefaultFilter;
 				wxImage																		m_pDefaultImage;
+				TimerDirectory*															m_pTimerDirectory;
+				DropTargetSelectImages*													m_pDropTarget;
+				std::list<std::string>													m_fileSpecs;
+				wxImage*																		m_pwxImagePreview;
 
 				virtual wxArrayString GetSelectedPaths();
 				virtual void OnSelectFiles(wxCommandEvent &event);
 
-				virtual void AddImage();
+		public:
 				virtual void AddImage(const wxString& path);
-				
-				virtual void OnRemoveAll(wxCommandEvent &event);
+		protected:
+				virtual void OnPreviewClick(wxCommandEvent &event);
 				virtual void OnThumbLeftDClickSelected(wxCommandEvent& event);
+				virtual void OnThumbRightClickSelected(wxCommandEvent& event);				
+				virtual void ShowPreview();
+				virtual void OnHidePreview(wxCommandEvent& event);
+				virtual void HidePreview();
+				virtual void OnRemoveAll(wxCommandEvent &event);
 				virtual void OnImagenesKeyDown(wxKeyEvent &event);
+				virtual void OnDeleteSelectedThumbnails(wxCommandEvent &event);
+				virtual void DeleteSelectedThumbnails();
 
+				virtual void UnCheckAll();
 				virtual void OnUbicacionClick(wxCommandEvent& event);
+				virtual void SetUbicacion(GIL::Ubicacion* ubicacion, int id);
+				GIL::Ubicacion* GetUbicacionSelected();
 
 			//region "Metodos heredados de IPasoWizard"
 				virtual void Attach(wxSizer *sizer);
@@ -77,6 +93,8 @@ namespace GNC {
 
 				virtual bool Cancelar();
 
+				virtual void OnCancelled();
+
 				virtual bool Validar();
 			//endregion
 
