@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: wxwizardimportacionginkgo.cpp 3913 2011-07-04 11:45:56Z tovar $
+ *  $Id: wxwizardimportacionginkgo.cpp 4178 2011-09-23 06:48:26Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -107,11 +107,14 @@ namespace GNC {
 				//se pillan los pasos
 				std::list<IPasoWizard*> pasosModulo;
 
-				IPasoWizard* pPaso0=new SelectImagesImportation(m_pPanelPrincipal,dir_temp,this,m_pControladorModulo->ImportaSeries(), m_pModeloIntegracion);
+				IPasoWizard* pPaso0=new SelectImagesImportation(m_pPanelPrincipal,dir_temp,this, m_pModeloIntegracion);
 				pasosModulo.push_back(pPaso0);				
 				
 				m_pControladorModulo->GetPasosImportacion(this,pasosModulo, m_pPanelPrincipal,dir_temp, m_pModeloIntegracion);
-				
+				if (m_pModeloIntegracion.IsValid()) {
+					m_pModeloIntegracion->UIDModulo = m_pControladorModulo->GetUID();
+				}
+
 				for(std::list<IPasoWizard*>::iterator it=pasosModulo.begin();it!=pasosModulo.end();++it){
 					m_ListaPasos.push_back(*it);
 					(*it)->AsignarListaFicheros(m_ListaFicheros);
@@ -174,7 +177,12 @@ namespace GNC {
 		
 		void wxWizardImportacionGinkgo::OnCancelarClick(wxCommandEvent&)
 		{
-			Close();
+			if ((*m_currentPaso)->AllowCancel()) {
+				for(ListaPasos::iterator it=m_ListaPasos.begin();it!=m_ListaPasos.end();++it){
+					(*it)->OnCancelled();
+				}
+				Close();
+			}
 		}
 		
 		void wxWizardImportacionGinkgo::OnSiguienteClick(wxCommandEvent&)
@@ -194,10 +202,13 @@ namespace GNC {
 
 					std::list<IPasoWizard*> pasosModulo;
 					
-					IPasoWizard* pPaso0 = new SelectImagesImportation(m_pPanelPrincipal, dir_temp, this, m_pControladorModulo->ImportaSeries(), m_pModeloIntegracion);
+					IPasoWizard* pPaso0 = new SelectImagesImportation(m_pPanelPrincipal, dir_temp, this, m_pModeloIntegracion);
 					pasosModulo.push_back(pPaso0);
 					
 					m_pControladorModulo->GetPasosImportacion(this,pasosModulo,m_pPanelPrincipal,dir_temp,m_pModeloIntegracion);
+					if (m_pModeloIntegracion.IsValid()) {
+						m_pModeloIntegracion->UIDModulo = m_pControladorModulo->GetUID();
+					}
 					
 					for(std::list<IPasoWizard*>::iterator it=pasosModulo.begin();it!=pasosModulo.end();++it){
 						m_ListaPasos.push_back(*it);
