@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: aboutdialog.cpp 3934 2011-07-07 08:47:50Z tovar $
+ *  $Id: aboutdialog.cpp 4117 2011-09-02 09:06:53Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -64,7 +64,7 @@ AboutDialog::AboutDialog(wxWindow* pPadre):AboutDialogBase(pPadre)
 	m_pCreditsText->WriteText(wxT("\n"));
 	m_pCreditsText->WriteText(_("Japanese: Noriya Yokohama"));
 	m_pCreditsText->WriteText(wxT("\n"));
-	m_pCreditsText->WriteText(_("German: Sebastian Hilbert and Karsten Hilbert"));
+	m_pCreditsText->WriteText(_("German: Sebastian Hilbert"));
 	m_pCreditsText->WriteText(wxT("\n"));
 	m_pCreditsText->WriteText(_("Turkish: zeugma (sunder67)"));
 	m_pCreditsText->WriteText(wxT("\n"));
