@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: ventanaprincipal.cpp 3984 2011-07-13 11:30:41Z tovar $
+ *  $Id: ventanaprincipal.cpp 4168 2011-09-21 09:14:16Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -58,6 +58,7 @@
 #include <main/gui/pacsupload/wxwizarduploadpacs.h>
 #include <main/gui/hl7controlwindow/ventanacontrolhl7.h>
 #include <main/gui/logcontrolwindow/ventanacontrollogs.h>
+#include <main/gui/startup/startupview.h>
 
 #include <api/globals.h>
 #include <api/ivista.h>
@@ -122,6 +123,7 @@
 #define ID_ONLINE_MANUAL 1079
 #define ID_PRIMER_FILTRO 1080
 #define ID_EXTENSIONS_SUPPORT 1081
+#define ID_START_PAGE 1082
 
 
 EventoProgreso::EventoProgreso(TipoProgreso tipo, long threadId)
@@ -621,7 +623,7 @@ void VentanaPrincipal::OnDropDownAcquire(wxAuiToolBarEvent& event)
 
 		menuPopup.Append( pMenuAbrirFichero );
 		menuPopup.Append( pMenuAbrirDirectorio );
-		if(GNC::GCS::ControladorPermisos::Instance()->Get("core.adquisicion","pacs")) {
+		if(GNC::GCS::ControladorPermisos::Instance()->Get("core.pacs.limits","pacs_acquisition")) {
 			menuPopup.AppendSeparator();
 			menuPopup.Append( m_pMenuAdquirir );
 		} else {
@@ -692,6 +694,28 @@ void VentanaPrincipal::OnCheckForUpdates(wxCommandEvent& /*event*/)
 	}
 }
 
+/*startup page*/
+void VentanaPrincipal::OnShowStartupPage(wxCommandEvent& /*event*/)
+{
+	ShowStartupPage();
+}
+
+void VentanaPrincipal::ShowStartupPage()
+{
+	GNC::GCS::IControladorVistas* pCtrlVistas = GNC::GCS::ControladorVistas::Instance();
+	SuperFreeze();
+	GnkPtr<GNC::GUI::StartUpStudy> study(new GNC::GUI::StartUpStudy());
+	study->Entorno = GNC::Entorno::Instance();
+	study->Modulo = NULL;
+	study->VentanaPadre = pCtrlVistas->GetRootWindow();
+	GNC::GCS::IVista* pView = new GNC::GUI::StartUpView(study);
+	pCtrlVistas->Registrar(pView);
+	
+	GnkPtr<GIL::IModeloIntegracion> ptr;
+	GNC::Entorno::Instance()->GetControladorCarga()->CargaAsincrona(pView, ptr, "", false);
+	SuperThaw();
+}
+
 void VentanaPrincipal::OnAdquirir(wxCommandEvent& WXUNUSED(event))
 {
 	GNC::GUI::DialogoAdquisicion::Instance()->Show();
@@ -1479,6 +1503,13 @@ void VentanaPrincipal::OnInicioAplicacion(wxCommandEvent &)
 		}
 	}
 
+	//start page...
+	bool defaultValue = GNC::GCS::ControladorPermisos::Instance()->Get("core.startup","startupdefaultvalue");
+	bool showOnStartup;
+	GNC::GCS::ConfigurationController::Instance()->readBoolUser("/GinkgoCore/News", "ShowOnStartUp", showOnStartup, defaultValue);
+	if (showOnStartup) {
+		ShowStartupPage();
+	}
 
 	//si viene un parametro y es un directorio... abrir directamente
 	if(!pathOfFile.empty())
@@ -1492,65 +1523,95 @@ void VentanaPrincipal::OnInicioAplicacion(wxCommandEvent &)
 void VentanaPrincipal::EjecutarParametro(const wxString cadena, bool doLogin)
 {
 	std::string xmlString("");
-
-	if(wxDir::Exists(cadena)){
-		if(doLogin) {
-			Login();
+	
+	wxFileName path = cadena;
+	bool error = false;
+	
+	if (path.IsOk()) {
+		
+		LOG_DEBUG("Core", "Interpretando " << std::string(TOPATH(path.GetFullPath())).c_str());
+		if (path.IsRelative()) {
+			LOG_DEBUG("Core", "Convirtiendo ruta en absoluta");
+			#if defined(__WXGTK__)
+			
+			char* invocation_dir = getenv("INVOCATION_DIR");					
+			if (invocation_dir != NULL) {
+				wxString invocationDir = wxString::FromUTF8(invocation_dir);
+				if (!invocationDir.IsEmpty()) {
+					path = invocationDir + wxFileName::GetPathSeparator() + path.GetFullPath();
+				}
+			}
+			#else
+			path.MakeAbsolute();
+			#endif
+			LOG_DEBUG("Core", "Ruta absoluta: " << std::string(TOPATH(path.GetFullPath())).c_str());
 		}
-		std::list<std::string> rutas;
-		rutas.push_back(std::string(TOPATH( cadena )));
-		GNC::GCS::Eventos::EventoAddFicheroHistorial* pEvt = new GNC::GCS::Eventos::EventoAddFicheroHistorial(rutas,true);
-		GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(pEvt);
-		return ;
-	} else if(wxFile::Exists(cadena)){
 
-		//estamos ante un fichero
-		//se mira a ver si a partir del byte 128 pone DICM
-		wxFile fichero(cadena,wxFile::read);
+		if(wxDirExists(path.GetFullPath()) && path.IsDirReadable()){
+			if(doLogin) {
+				Login();
+			}
+			std::list<std::string> rutas;
+			rutas.push_back(std::string(TOPATH( path.GetFullPath() )));
+			GNC::GCS::Eventos::EventoAddFicheroHistorial* pEvt = new GNC::GCS::Eventos::EventoAddFicheroHistorial(rutas,true);
+			GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(pEvt);
+			return ;
+		} else if(path.FileExists() && path.IsFileReadable()){
 
-		bool esDicom = false;
-		if(fichero.IsOpened()){
-			char buffer[128];
-			if(fichero.Read(buffer,128) == 128){
-				char numeroMagico[4];
-				if(fichero.Read(numeroMagico,4) == 4){
-					std::string str(numeroMagico,4);
-					if(str == "DICM") {
-						esDicom = true;
+			//estamos ante un fichero
+			//se mira a ver si a partir del byte 128 pone DICM
+			wxFile fichero(path.GetFullPath(), wxFile::read);
+
+			bool esDicom = false;
+			if(fichero.IsOpened()){
+				char buffer[128];
+				if(fichero.Read(buffer,128) == 128){
+					char numeroMagico[4];
+					if(fichero.Read(numeroMagico,4) == 4){
+						std::string str(numeroMagico,4);
+						if(str == "DICM") {
+							esDicom = true;
+						}
+					}
+				}
+			}
+			if(esDicom) {
+				if (doLogin) {
+					Login();
+				}
+				//si no es un xml pues sera un dicom...
+				std::list<std::string> rutas;
+				rutas.push_back(std::string(TOPATH(path.GetFullPath()) ));
+				GNC::GCS::Eventos::EventoAddFicheroHistorial* pEvt = new GNC::GCS::Eventos::EventoAddFicheroHistorial(rutas,true);
+				GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(pEvt);
+			} else {
+				//se lee el modelo
+				wxXmlDocument documento;
+				if(documento.Load(path.GetFullPath())) {
+					wxStringOutputStream out;
+					documento.Save(out);
+					xmlString=out.GetString().ToUTF8();
+				} else {
+					LOG_ERROR("GIL/WF", "Error al interpretar el XML de integración: XML mal formado");
+					wxMessageBox(_("Malformed XML"),_("Error"),wxICON_INFORMATION);
+					if (doLogin) {
+						Login();
 					}
 				}
 			}
 		}
-		if(esDicom) {
-			if (doLogin) {
-				Login();
-			}
-			//si no es un xml pues sera un dicom...
-			std::list<std::string> rutas;
-			rutas.push_back(std::string(TOPATH( cadena) ));
-			GNC::GCS::Eventos::EventoAddFicheroHistorial* pEvt = new GNC::GCS::Eventos::EventoAddFicheroHistorial(rutas,true);
-			GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(pEvt);
-		} else {
-			//se lee el modelo
-			wxXmlDocument documento;
-			if(documento.Load(cadena)) {
-				wxStringOutputStream out;
-				documento.Save(out);
-				xmlString=out.GetString().ToUTF8();
-			} else {
-				LOG_ERROR("GIL/WF", "Error al interpretar el XML de integración: XML mal formado");
-				wxMessageBox(_("Malformed XML"),_("Error"),wxICON_INFORMATION);
-				if (doLogin) {
-					Login();
-				}
-			}
+		else {
+			error = true;
 		}
 	}
 	else {
-		LOG_ERROR("GIL/WF", "Error al interpretar los parámetros de la línea de comandos. No existe el fichero o directorio (" << cadena.ToUTF8() << ")" );
+		error = true;
+	}
+	if (error) {
+		LOG_ERROR("GIL/WF", "Error al interpretar los parámetros de la línea de comandos. No existe el fichero o directorio (" << path.GetFullPath().ToUTF8() << ")" );
 			wxMessageBox(
 				_("Error in interpreting the parameters of the command line. The file or directory doesn't exist (")
-				+ cadena
+				+ path.GetFullPath()
 				+ wxString::FromUTF8(")")
 				,_("Error"), wxICON_INFORMATION);
 			if (doLogin) {
@@ -1564,7 +1625,7 @@ void VentanaPrincipal::EjecutarParametro(const wxString cadena, bool doLogin)
 		try {
 
 			//se considera que el parametro es un ticket
-			std::string ticket(cadena.ToUTF8());
+			std::string ticket(TOPATH(path.GetFullPath()));
 			xmlString = GIL::GnkNetwork::GnkSOAP::ClienteSOAPIntegracion::GetXMLPeticion(ticket);
 
 
@@ -1581,10 +1642,13 @@ void VentanaPrincipal::EjecutarParametro(const wxString cadena, bool doLogin)
 					modelo->atendido = true;
 				if(modelo->accion == GIL::IModeloIntegracion::TA_Dicomizar) {
 					//se busca el dicomizador del modulo indicado, habra un mapa que transformara sid en uids de modulo
-					std::string uidModulo = controlador.GetUID(modelo->idPlantilla);
-					modelo->UIDModulo = uidModulo;
-					if (GNC::ControladorExtensiones::Instance()->ObtenerModulo(uidModulo) == NULL) {
-						throw GIL::HL7::HL7Exception("No existe el modulo asociado", "Modelo", true);
+					std::string uidModulo("");
+					if (modelo->idPlantilla != "") {
+						uidModulo = controlador.GetUID(modelo->idPlantilla);
+						modelo->UIDModulo = uidModulo;
+						if (GNC::ControladorExtensiones::Instance()->ObtenerModulo(uidModulo) == NULL) {
+							throw GIL::HL7::HL7Exception("No existe el modulo asociado", "Modelo", true);
+						}
 					}
 					bool noerror = false;
 
@@ -1752,7 +1816,7 @@ void VentanaPrincipal::RefrescarMenus()
 #endif
 		pMenuArchivo->Append( pMenuAbrirFichero );
 		pMenuArchivo->Append( pMenuAbrirDirectorio );
-		if(GNC::GCS::ControladorPermisos::Instance()->Get("core.adquisicion","pacs")) {
+		if(GNC::GCS::ControladorPermisos::Instance()->Get("core.pacs.limits","pacs_acquisition")) {
 			pMenuArchivo->AppendSeparator();
 			pMenuArchivo->Append( m_pMenuAdquirir );
 		} else {
@@ -1766,7 +1830,7 @@ void VentanaPrincipal::RefrescarMenus()
 		pMenuArchivo->AppendSeparator();
 		pMenuArchivo->Append( m_pMenuGuardar );
 		pMenuArchivo->AppendSeparator();
-		if(GNC::GCS::ControladorPermisos::Instance()->Get("core.menu","subir pacs")) {
+		if(GNC::GCS::ControladorPermisos::Instance()->Get("core.pacs.limits","pacs_upload")) {
 			pMenuArchivo->Append(m_pMenuSubirPacs);
 		} else { 
 			delete m_pMenuSubirPacs;
@@ -1801,6 +1865,7 @@ void VentanaPrincipal::RefrescarMenus()
 		wxMenuItem*  m_pMenuCheckUpdates = new wxMenuItem( pMenuAyuda, ID_CHECK_UPDATES, wxString( _("Check for updates") ), _("Check for newest versions"), wxITEM_NORMAL );
 		wxMenuItem*  pMenuOnlineSupport = new wxMenuItem( pMenuAyuda, ID_ONLINE_SUPPORT, wxString( _("Need support ...") ), _("Need support ..."), wxITEM_NORMAL );
 		wxMenuItem*  pMenuExtSupport = new wxMenuItem( pMenuAyuda, ID_EXTENSIONS_SUPPORT, wxString( _("Get Extensions ...") ), _("Get Extensions ..."), wxITEM_NORMAL );
+		wxMenuItem*  pMenuStartPage = new wxMenuItem( pMenuAyuda, ID_START_PAGE, wxString( _("Start page ...") ), _("Ginkgo CADx Start Page ..."), wxITEM_NORMAL );
 		wxMenuItem*  m_pMenuAcercaDe = new wxMenuItem( pMenuAyuda, ID_ACERCA_DE, wxString( _("About &Ginkgo CADx ...") ), _("About Ginkgo CADx ..."), wxITEM_NORMAL );
 
 		#ifdef __WXMSW__
@@ -1819,10 +1884,12 @@ void VentanaPrincipal::RefrescarMenus()
 		pMenuAyuda->Append( pMenuExtSupport );
 		pMenuAyuda->AppendSeparator();		
 		pMenuAyuda->Append( m_pMenuCheckUpdates );
+		pMenuAyuda->Append( pMenuStartPage);
 		pMenuAyuda->AppendSeparator();
 		pMenuAyuda->Append( m_pMenuAcercaDe );
 
 		this->Connect( pMenuOnlineHelp->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaPrincipal::OnOnlineHelp ) );
+		this->Connect( pMenuStartPage->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaPrincipal::OnShowStartupPage ) );
 		this->Connect( m_pMenuCheckUpdates->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaPrincipal::OnCheckForUpdates ) );
 		this->Connect( m_pMenuAcercaDe->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaPrincipal::OnAcercaDe ) );
 		this->Connect( pMenuOnlineSupport->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaPrincipal::OnOnlineSupport ) );
