@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: ventanaprincipal.h 3950 2011-07-08 11:41:01Z carlos $
+ *  $Id: ventanaprincipal.h 4158 2011-09-19 13:25:20Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -158,6 +158,10 @@ public:
 	/* Evento de lanzamiento de la comprobacion de actualizaciones */
 	virtual void OnCheckForUpdates(wxCommandEvent& event);
 
+	/*startup page*/
+	void OnShowStartupPage(wxCommandEvent& event);
+	void ShowStartupPage();
+
 	/* Evento de apertura de estudio */
 	virtual void OnAdquirir(wxCommandEvent& event);
 
@@ -230,7 +234,6 @@ public:
 
 	void OnMenuPrimerPlanoPestaniaActiva(wxCommandEvent& event);
 
-
 	/*Eventos de impresion*/
 	void OnMenuImprimir(wxCommandEvent& event);
 	void OnMenuImprimirUpdateUI(wxUpdateUIEvent& event);
