@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: paneltags.cpp 3834 2011-05-10 07:42:57Z carlos $
+ *  $Id: paneltags.cpp 4158 2011-09-19 13:25:20Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -59,7 +59,7 @@ void GNC::GUI::PanelTags::MostrarOcultarPanelTags()
 void GNC::GUI::PanelTags::SetEstudio(GnkPtr<GNC::GCS::IContextoEstudio> pEstudio)
 {
 	m_pTags->Clear();
-	if(!pEstudio.IsValid())
+	if(!pEstudio.IsValid() || pEstudio->IndiceFicheroActivo < 0)
 	{
 		
 		return;
