@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: licencia.h 4017 2011-07-14 07:10:37Z carlos $
+ *  $Id: licencia.h 4180 2011-09-23 07:21:29Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -14,11 +14,21 @@
 #pragma once
 #include <string>
 
-#define GINKGO_VERSION     2
-#define GINKGO_SUB_VERSION 5
-#define GINKGO_SUB_RELEASE 1
-#define GINKGO_BUILD       0
-#define GINKGO_CODENAME    "final"
+#if !defined(GINKGO_VERSION)
+	#define GINKGO_VERSION     2
+#endif
+#if !defined(GINKGO_SUB_VERSION)
+	#define GINKGO_SUB_VERSION 5
+#endif
+#if !defined(GINKGO_SUB_RELEASE)
+	#define GINKGO_SUB_RELEASE 4
+#endif
+#if !defined(GINKGO_BUILD)
+	#define GINKGO_BUILD       1
+#endif
+#if !defined(GINKGO_CODENAME)
+	#define GINKGO_CODENAME    "final"
+#endif
 #define GINKGO_COPYRIGHT   "© 2011"
 
 #if !defined(INTERNET_DIST)
@@ -29,8 +39,8 @@
 // "<?xml version=\"1.0\"?>\n"
 // "<permisos>\n"
 // "<permiso namespace=\"core\" id=\"default\" accion=\"activar\"/>"
-// "<permiso namespace=\"core.adquisicion\" id=\"pacs\" accion=\"desactivar\"/>"
-// "<permiso namespace=\"core.menu\" id=\"subir pacs\" accion=\"activar\"/>"
+// "<permiso namespace=\"core.pacs.limits\" id=\"pacs\" accion=\"desactivar\"/>"
+// "<permiso namespace=\"core.pacs.limits\" id=\"pacs_upload\" accion=\"activar\"/>"
 // "<permiso namespace=\"core.menu\" id=\"configuracion\" accion=\"desactivar\"/>"
 // "<permiso namespace=\"core.menu\" id=\"filtrado\" accion=\"activar\"/>"
 // "<permiso namespace=\"atencionprimaria\" id=\"dicomizador\" accion=\"activar\"/>"
