@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: ginkgoresourcemanager.cpp 3756 2011-04-25 08:57:12Z tovar $
+ *  $Id: ginkgoresourcemanager.cpp 4072 2011-08-10 13:45:52Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -30,6 +30,7 @@
 #include "wizards/ico_barra_superior.h"
 #include "barralayout/iconos.h"
 #include "menustabs/iconos.h"
+#include "barracine/iconos.h"
 #include <api/globals.h>
 
 #include <wx/mstream.h>
@@ -318,4 +319,10 @@ const wxBitmap GinkgoResourcesManager::MenusTabs::GetIcoGrid2Col(){return wxMEMO
 const wxBitmap GinkgoResourcesManager::MenusTabs::GetIcoGrid3Col(){return wxMEMORY_BITMAP(ico_grid_3_col); }
 const wxBitmap GinkgoResourcesManager::MenusTabs::GetIcoReagrupar(){return wxMEMORY_BITMAP(ico_reagrupar); }
 
-
+// Barra Cine
+wxBitmap GinkgoResourcesManager::BarraCine::GetIcoPlay(){return wxMEMORY_BITMAP(ico_play); }
+wxBitmap GinkgoResourcesManager::BarraCine::GetIcoBucle(){return wxMEMORY_BITMAP(ico_bucle); }
+wxBitmap GinkgoResourcesManager::BarraCine::GetIcoNoBucle(){return wxMEMORY_BITMAP(ico_no_bucle); }
+wxBitmap GinkgoResourcesManager::BarraCine::GetIcoStop(){return wxMEMORY_BITMAP(ico_stop); }
+wxBitmap GinkgoResourcesManager::BarraCine::GetIcoPause(){return wxMEMORY_BITMAP(ico_pause); }
+wxBitmap GinkgoResourcesManager::BarraCine::GetIcoCine(){return wxMEMORY_BITMAP(ico_cine); }
