@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: vtkginkgoimageviewer.cpp 3814 2011-05-01 11:36:06Z carlos $
+ *  $Id: vtkginkgoimageviewer.cpp 4090 2011-08-25 12:17:45Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -189,9 +189,9 @@ public:
 		PlaneSource->SetPoint2(center[0],bounds[2],bounds[5]);
 
 		Textura->SetPremultipliedAlpha(1.0);
-		Textura->SetInterpolate(0);
+		Textura->SetInterpolate(1);
 		Textura->RepeatOff();
-		TexturaOverlay->SetInterpolate(0);
+		TexturaOverlay->SetInterpolate(1);
 		TexturaOverlay->RepeatOff();
 		TexturaOverlay->MapColorScalarsThroughLookupTableOn();
 		vtkLookupTable* tblover = vtkLookupTableManager::GetOverlayLooupTable();
@@ -1708,8 +1708,17 @@ bool vtkGinkgoImageViewer::GetShowAnnotations()
 
 //--------------------------------------------------------------------
 //region Propiedades
-void vtkGinkgoImageViewer::SetInterpolationMode(int /*enable*/)
+void vtkGinkgoImageViewer::SetInterpolationMode(int enable)
 {
+	Pipeline& p  = members->Pipeline;
+	p.Textura->SetInterpolate(enable);
+	p.TexturaOverlay->SetInterpolate(enable);
+}
+
+int vtkGinkgoImageViewer::GetInterpolationMode()
+{
+	Pipeline& p  = members->Pipeline;
+	return p.Textura->GetInterpolate();
 }
 
 bool vtkGinkgoImageViewer::GetWholeExtent(int extent[6]) const
