@@ -18,6 +18,7 @@
 #include <wx/aui/auibar.h>
 #include <wx/dcbuffer.h>
 #include <wx/settings.h>
+#include <wx/window.h>
 #include <resources/ginkgoresourcemanager.h>
 #include <algorithm>
 
@@ -42,7 +43,7 @@ VerticalHeader::VerticalHeader(wxWindow *parent, wxWindowID winid, const wxPoint
 
 	int x = -1,y = -1;
 	if (m_titulo != wxEmptyString) {
-		wxPaintDC dc;
+		wxClientDC dc(this);;
 		dc.SetFont(m_fuente);
 		dc.GetTextExtent(m_titulo, &x, &y, NULL, NULL, NULL);
 	}
@@ -858,6 +859,198 @@ SubTitledPanelSeparatorH::~SubTitledPanelSeparatorH()
 {
 }
 
+/////////////////////////////////////////////GinkgoBoxPanel/////////////////////////////////////
+GinkgoBoxPanel::GinkgoBoxPanel(wxWindow *parent,
+         wxWindowID winid ,
+         const wxPoint& pos,
+         const wxSize& size ,
+			long style):wxPanel(parent, winid, pos, size, style)
+{
+	m_backgroudColor = wxColour(248,247,243);
+	m_borderColor = wxColour(216, 215, 209, 255);
+	SetBackgroundColour(m_backgroudColor);
+
+	this->Connect( wxEVT_PAINT, wxPaintEventHandler( GinkgoBoxPanel::OnPaint ), NULL, this );
+}
+
+GinkgoBoxPanel::~GinkgoBoxPanel()
+{
+	this->Disconnect( wxEVT_PAINT, wxPaintEventHandler( GinkgoBoxPanel::OnPaint ), NULL, this );	
+}
+
+void GinkgoBoxPanel::OnPaint(wxPaintEvent &event)
+{
+	wxPaintDC dc(this);
+
+	dc.SetBrush(wxBrush(m_borderColor,wxTRANSPARENT));
+	dc.SetPen(wxPen(m_borderColor, 1, wxSOLID));
+
+	dc.DrawRectangle(wxRect(wxPoint(0,0), wxPoint(dc.GetSize().x-1, dc.GetSize().y-1)));
+	event.Skip(false);
+}
+
+/////////////////////////////////////////////GinkgoGauge/////////////////////////////////////
+GinkgoGauge::GinkgoGauge(wxWindow *parent,
+            wxWindowID winid,
+            const wxPoint& pos,
+            const wxSize& size,
+				long style): wxPanel(parent, winid, pos, size, style)
+{
+	SetMinSize(wxSize(150, 15));
+	m_progress = 0.0f;
+	wxFont font(8, GetFont().GetFamily(), GetFont().GetStyle(), GetFont().GetWeight());
+	SetFont(font);
+	wxWindow::SetBackgroundStyle(wxBG_STYLE_CUSTOM);
+
+	wxClientDC dc(this);
+	dc.SetFont(font);
+	int height,width;
+	dc.GetTextExtent(wxT("000% "), &width, &height, NULL, NULL, NULL);
+	m_maxSizeOfText = GetSize().x - (width +15);
+
+	RecreateBuffer(size);
+
+
+	this->Connect( wxEVT_PAINT, wxPaintEventHandler( GinkgoGauge::OnPaint ), NULL, this );
+	this->Connect( wxEVT_ERASE_BACKGROUND, wxEraseEventHandler( GinkgoGauge::OnEraseBackground ), NULL, this);
+	this->Connect( wxEVT_SIZE, wxSizeEventHandler( GinkgoGauge::OnSize ), NULL, this );
+}
+
+GinkgoGauge::~GinkgoGauge()
+{
+	this->Disconnect( wxEVT_PAINT, wxPaintEventHandler( GinkgoGauge::OnPaint ), NULL, this );
+	this->Disconnect( wxEVT_ERASE_BACKGROUND, wxEraseEventHandler( GinkgoGauge::OnEraseBackground ), NULL, this);
+	this->Disconnect( wxEVT_SIZE, wxSizeEventHandler( GinkgoGauge::OnSize ), NULL, this );
+}	
+
+void GinkgoGauge::SetStatus(const wxString& status)
+{
+	m_status = status;
+	wxClientDC dc(this);
+	dc.SetFont(GetFont());
+	int width,height;
+	dc.GetTextExtent(m_status, &width, &height, NULL, NULL, NULL);
+	while (width > m_maxSizeOfText && m_status.size() > 2) {
+		m_status = m_status.substr(0, m_status.size() - 2);				
+		dc.GetTextExtent(m_status, &width, &height, NULL, NULL, NULL);
+	} 
+
+	Refresh(true);
+}
+
+void GinkgoGauge::SetProgress(float progress)
+{
+	if (progress >= 0.0f && progress <= 1.0f) {
+		m_progress = progress;
+		Refresh(true);
+	}
+}
+
+void GinkgoGauge::OnPaint(wxPaintEvent &event)
+{
+	wxBufferedPaintDC dc(this, m_bufferBitmap);
+	PrepareDC(dc);
+
+	dc.SetFont(GetFont());
+	dc.SetPen( wxPen( m_borderColour, 1, wxSOLID ) );
+	dc.SetBrush(wxColour(255,255,255));
+
+	int width = dc.GetSize().x;
+	int height = dc.GetSize().y;
+	wxRect cr(0,0, width, height);
+
+	dc.DrawRectangle(cr);
+
+	cr.width = (int) ( (float)width * m_progress );
+
+	dc.GradientFillLinear(cr, m_startColour, m_endColour, wxEAST);
+
+	int func = dc.GetLogicalFunction();
+	dc.SetLogicalFunction(wxXOR);
+
+	wxCoord tx = 0, ty = 0;
+	wxString str = wxString::Format(wxT("%.00f%% "), 100.0f * m_progress) + m_status;
+	dc.GetTextExtent(str, &tx, &ty, NULL, NULL, NULL);
+
+
+	dc.DrawText(str, (width >> 1)  - (tx >> 1), (height >> 1) - (ty >> 1) );
+	dc.SetLogicalFunction(func);
+	event.Skip(false);
+}
+
+void GinkgoGauge::OnEraseBackground( wxEraseEvent&  )
+{
+}
+
+
+void GinkgoGauge::OnSize(wxSizeEvent& )
+{
+	RecreateBuffer();
+}
+
+void GinkgoGauge::SetMinSize(const wxSize &minSize)
+{
+	wxPanel::SetMinSize(minSize);
+	RecreateBuffer();
+}
+
+void GinkgoGauge::SetSize(const wxSize &minSize)
+{
+	wxPanel::SetSize(minSize);
+	RecreateBuffer();
+}
+
+void GinkgoGauge::SetColorSchema(TColorSchema schema)
+{
+	switch (schema) {
+		case TCS_BLUE:
+			m_fontColour = wxColour(0,0,0);
+			m_startColour = wxColour(224, 237, 255);
+			m_endColour = wxColour(119, 169, 255);
+			m_borderColour = wxColour(58, 143, 255);
+			break;
+		case TCS_RED:
+			m_fontColour = wxColour(0,0,0);
+			m_startColour = wxColour(255, 224, 237);
+			m_endColour = wxColour(255, 169, 119);
+			m_borderColour = wxColour(255, 0, 0);
+			break;
+		case TCS_GREY:
+			m_fontColour = wxColour(0,0,0);
+			m_startColour = wxColour(237, 237, 237);
+			m_endColour = wxColour(100, 100, 100);
+			m_borderColour = wxColour(143, 143, 143);
+			break;
+		case TCS_GREEN:
+			m_fontColour = wxColour(0,0,0);
+			m_startColour = wxColour(237, 255, 224);
+			m_endColour = wxColour(120, 198, 83);
+			m_borderColour = wxColour(143, 255, 58);
+			break;
+	}
+	SetForegroundColour(m_fontColour);
+}
+
+bool GinkgoGauge::RecreateBuffer(const wxSize& size)
+{
+    wxSize sz = size;
+    if (sz == wxDefaultSize)
+        sz = GetClientSize();
+
+    if (sz.x < 1 || sz.y < 1)
+        return false;
+
+	 wxClientDC dc(this);
+	 dc.SetFont(GetFont());
+	 int height,width;
+	 dc.GetTextExtent(wxT("000% "), &width, &height, NULL, NULL, NULL);
+	 m_maxSizeOfText = sz.x - (width +15);
+
+    if (!m_bufferBitmap.Ok() || m_bufferBitmap.GetWidth() < sz.x || m_bufferBitmap.GetHeight() < sz.y)
+        m_bufferBitmap = wxBitmap(sz.x, sz.y);
+
+    return m_bufferBitmap.Ok();
+}
 
 
 
