@@ -331,3 +331,66 @@ public:
 protected:
 	int m_separacion;
 };
+
+class EXTAPI GinkgoBoxPanel: public wxPanel {
+public:
+	GinkgoBoxPanel(wxWindow *parent,
+            wxWindowID winid = wxID_ANY,
+            const wxPoint& pos = wxDefaultPosition,
+            const wxSize& size = wxDefaultSize,
+            long style = wxTAB_TRAVERSAL | wxNO_BORDER);
+	~GinkgoBoxPanel();
+protected:
+
+	virtual void OnPaint(wxPaintEvent &event);
+
+	wxColour m_backgroudColor;
+	wxColour m_borderColor;
+};
+
+
+class EXTAPI GinkgoGauge: public wxPanel {
+public:
+	typedef enum {
+		TCS_BLUE,
+		TCS_RED,
+		TCS_GREY,
+		TCS_GREEN
+	} TColorSchema;
+
+	GinkgoGauge(wxWindow *parent,
+            wxWindowID winid = wxID_ANY,
+            const wxPoint& pos = wxDefaultPosition,
+            const wxSize& size = wxDefaultSize,
+            long style = wxTAB_TRAVERSAL | wxNO_BORDER);
+	~GinkgoGauge();
+	
+	virtual void SetStatus(const wxString& status);
+	virtual void SetProgress(float progress);
+
+	virtual void SetMinSize(const wxSize &minSize);
+	virtual void SetSize(const wxSize &minSize);
+	
+	virtual void SetColorSchema(TColorSchema schema);
+
+protected:
+
+	virtual void OnPaint(wxPaintEvent &event);
+	virtual void OnEraseBackground( wxEraseEvent& event );
+	virtual void OnSize(wxSizeEvent& event);
+	virtual bool RecreateBuffer(const wxSize& size = wxDefaultSize);
+
+
+	wxString m_status;
+	float m_progress;
+	int m_maxSizeOfText;
+
+	/// Buffer bitmap
+   wxBitmap                m_bufferBitmap;
+	wxColour						m_fontColour;
+	wxColour						m_startColour;
+	wxColour						m_endColour;
+	wxColour						m_borderColour;
+};
+
+
