@@ -1,12 +1,21 @@
 #!/bin/bash
-VER=2.5.1.0
+
+GINKGO_VERSION=2
+GINKGO_SUB_VERSION=5
+GINKGO_SUB_RELEASE=4
+GINKGO_BUILD=1
+GINKGO_CODENAME="final"
+
+#########################################
+
+VER=${GINKGO_VERSION}.${GINKGO_SUB_VERSION}.${GINKGO_SUB_RELEASE}.${GINKGO_BUILD}
 if [ "X`uname`" == X"Darwin" ]; then
 	export COPYFILE_DISABLE=true
 	export COPY_EXTENDED_ATTRIBUTES_DISABLED=true
 	mkdir build >/dev/null 2>&1
 	cd build || exit 1
-	cmake .. -DCMAKE_BUILD_TYPE=Release -DINTERNET_DIST:BOOL=TRUE -DBUILD_OPHTALMOLOGY_EXT:BOOL=FALSE -DBUILD_DERMATHOLOGY_EXT:BOOL=FALSE -DBUILD_VIDEO_EXT:BOOL=FALSE -DBUILD_LIGHT_VISUALIZATOR_EXT:BOOL=TRUE -DUSE_SYSTEM_SQLITE:BOOL=FALSE -DUSE_PATCHED_LIBS:BOOL=TRUE -DUSE_CUSTOM_WX:BOOL=TRUE -DUSE_CUSTOM_VTK:BOOL=TRUE -DUSE_CUSTOM_ITK:BOOL=TRUE -DUSE_CUSTOM_DCMTK=TRUE -DCUSTOM_PACKAGE:BOOL=TRUE -DGINKGO_VERSION:STRING=$VER -DCMAKE_INSTALL_PREFIX:STRING=./deploy || exit 1
-	cmake .. -DCMAKE_BUILD_TYPE=Release -DINTERNET_DIST:BOOL=TRUE -DBUILD_OPHTALMOLOGY_EXT:BOOL=FALSE -DBUILD_DERMATHOLOGY_EXT:BOOL=FALSE -DBUILD_VIDEO_EXT:BOOL=FALSE -DBUILD_LIGHT_VISUALIZATOR_EXT:BOOL=TRUE -DUSE_SYSTEM_SQLITE:BOOL=FALSE -DUSE_PATCHED_LIBS:BOOL=TRUE -DUSE_CUSTOM_WX:BOOL=TRUE -DUSE_CUSTOM_VTK:BOOL=TRUE -DUSE_CUSTOM_ITK:BOOL=TRUE -DUSE_CUSTOM_DCMTK=TRUE -DCUSTOM_PACKAGE:BOOL=TRUE -DGINKGO_VERSION:STRING=$VER -DCMAKE_INSTALL_PREFIX:STRING=./deploy || exit 1
+	cmake .. -DGINKGO_VERSION=${GINKGO_VERSION} -DGINKGO_SUB_VERSION=${GINKGO_SUB_VERSION} -DGINKGO_SUB_RELEASE=${GINKGO_SUB_RELEASE} -DGINKGO_BUILD=${GINKGO_BUILD} -DGINKGO_CODENAME=${GINKGO_CODENAME} -DCMAKE_BUILD_TYPE=Release -DINTERNET_DIST:BOOL=TRUE -DBUILD_OPHTALMOLOGY_EXT:BOOL=FALSE -DBUILD_DERMATHOLOGY_EXT:BOOL=FALSE -DBUILD_VIDEO_EXT:BOOL=FALSE -DBUILD_LIGHT_VISUALIZATOR_EXT:BOOL=TRUE -DUSE_SYSTEM_SQLITE:BOOL=FALSE -DUSE_PATCHED_LIBS:BOOL=TRUE -DUSE_CUSTOM_WX:BOOL=TRUE -DUSE_CUSTOM_VTK:BOOL=TRUE -DUSE_CUSTOM_ITK:BOOL=TRUE -DUSE_CUSTOM_DCMTK=TRUE -DCUSTOM_PACKAGE:BOOL=TRUE -DCMAKE_INSTALL_PREFIX:STRING=./deploy || exit 1
+	cmake .. -DGINKGO_VERSION=${GINKGO_VERSION} -DGINKGO_SUB_VERSION=${GINKGO_SUB_VERSION} -DGINKGO_SUB_RELEASE=${GINKGO_SUB_RELEASE} -DGINKGO_BUILD=${GINKGO_BUILD} -DGINKGO_CODENAME=${GINKGO_CODENAME} -DCMAKE_BUILD_TYPE=Release -DINTERNET_DIST:BOOL=TRUE -DBUILD_OPHTALMOLOGY_EXT:BOOL=FALSE -DBUILD_DERMATHOLOGY_EXT:BOOL=FALSE -DBUILD_VIDEO_EXT:BOOL=FALSE -DBUILD_LIGHT_VISUALIZATOR_EXT:BOOL=TRUE -DUSE_SYSTEM_SQLITE:BOOL=FALSE -DUSE_PATCHED_LIBS:BOOL=TRUE -DUSE_CUSTOM_WX:BOOL=TRUE -DUSE_CUSTOM_VTK:BOOL=TRUE -DUSE_CUSTOM_ITK:BOOL=TRUE -DUSE_CUSTOM_DCMTK=TRUE -DCUSTOM_PACKAGE:BOOL=TRUE -DCMAKE_INSTALL_PREFIX:STRING=./deploy || exit 1
 	make BUILD_ALL install || exit 1
 	DIR="Ginkgo CADx ${VER}"
 	rm -rf "$DIR"
@@ -73,8 +82,8 @@ else
 
 	mkdir build >/dev/null 2>&1
 	cd build || exit 1
-	cmake .. -DCMAKE_BUILD_TYPE=Release -DINTERNET_DIST:BOOL=TRUE -DBUILD_OPHTALMOLOGY_EXT:BOOL=FALSE -DBUILD_LIGHT_VISUALIZATOR_EXT:BOOL=TRUE -DBUILD_DERMATHOLOGY_EXT:BOOL=FALSE -DBUILD_VIDEO_EXT:BOOL=FALSE -DUSE_SYSTEM_SQLITE:BOOL=FALSE -DUSE_PATCHED_LIBS:BOOL=TRUE -DUSE_CUSTOM_WX:BOOL=TRUE -DUSE_CUSTOM_VTK:BOOL=TRUE -DUSE_CUSTOM_ITK:BOOL=TRUE -DUSE_CUSTOM_DCMTK=TRUE -DCUSTOM_PACKAGE:BOOL=TRUE -DGINKGO_VERSION:STRING=$VER -DCMAKE_INSTALL_PREFIX:STRING=./deploy || exit 1 
-	cmake .. -DCMAKE_BUILD_TYPE=Release -DINTERNET_DIST:BOOL=TRUE -DBUILD_OPHTALMOLOGY_EXT:BOOL=FALSE -DBUILD_LIGHT_VISUALIZATOR_EXT:BOOL=TRUE -DBUILD_DERMATHOLOGY_EXT:BOOL=FALSE -DBUILD_VIDEO_EXT:BOOL=FALSE -DUSE_SYSTEM_SQLITE:BOOL=FALSE -DUSE_PATCHED_LIBS:BOOL=TRUE -DUSE_CUSTOM_WX:BOOL=TRUE -DUSE_CUSTOM_VTK:BOOL=TRUE -DUSE_CUSTOM_ITK:BOOL=TRUE -DUSE_CUSTOM_DCMTK=TRUE -DCUSTOM_PACKAGE:BOOL=TRUE -DGINKGO_VERSION:STRING=$VER -DCMAKE_INSTALL_PREFIX:STRING=./deploy || exit 1 
+	cmake .. -DGINKGO_VERSION=${GINKGO_VERSION} -DGINKGO_SUB_VERSION=${GINKGO_SUB_VERSION} -DGINKGO_SUB_RELEASE=${GINKGO_SUB_RELEASE} -DGINKGO_BUILD=${GINKGO_BUILD} -DGINKGO_CODENAME=${GINKGO_CODENAME} -DCMAKE_BUILD_TYPE=Release -DINTERNET_DIST:BOOL=TRUE -DBUILD_OPHTALMOLOGY_EXT:BOOL=FALSE -DBUILD_LIGHT_VISUALIZATOR_EXT:BOOL=TRUE -DBUILD_DERMATHOLOGY_EXT:BOOL=FALSE -DBUILD_VIDEO_EXT:BOOL=FALSE -DUSE_SYSTEM_SQLITE:BOOL=FALSE -DUSE_PATCHED_LIBS:BOOL=TRUE -DUSE_CUSTOM_WX:BOOL=TRUE -DUSE_CUSTOM_VTK:BOOL=TRUE -DUSE_CUSTOM_ITK:BOOL=TRUE -DUSE_CUSTOM_DCMTK=TRUE -DCUSTOM_PACKAGE:BOOL=TRUE -DCMAKE_INSTALL_PREFIX:STRING=./deploy || exit 1 
+	cmake .. -DGINKGO_VERSION=${GINKGO_VERSION} -DGINKGO_SUB_VERSION=${GINKGO_SUB_VERSION} -DGINKGO_SUB_RELEASE=${GINKGO_SUB_RELEASE} -DGINKGO_BUILD=${GINKGO_BUILD} -DGINKGO_CODENAME=${GINKGO_CODENAME} -DCMAKE_BUILD_TYPE=Release -DINTERNET_DIST:BOOL=TRUE -DBUILD_OPHTALMOLOGY_EXT:BOOL=FALSE -DBUILD_LIGHT_VISUALIZATOR_EXT:BOOL=TRUE -DBUILD_DERMATHOLOGY_EXT:BOOL=FALSE -DBUILD_VIDEO_EXT:BOOL=FALSE -DUSE_SYSTEM_SQLITE:BOOL=FALSE -DUSE_PATCHED_LIBS:BOOL=TRUE -DUSE_CUSTOM_WX:BOOL=TRUE -DUSE_CUSTOM_VTK:BOOL=TRUE -DUSE_CUSTOM_ITK:BOOL=TRUE -DUSE_CUSTOM_DCMTK=TRUE -DCUSTOM_PACKAGE:BOOL=TRUE -DCMAKE_INSTALL_PREFIX:STRING=./deploy || exit 1 
 	make -j4 BUILD_ALL || exit 1
 	DIR=Ginkgo_CADx-${VER}_linux_${ARCH}
 	rm -rf $DIR
