@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: comandodicomizacionintegracion.cpp 3964 2011-07-11 22:17:46Z carlos $
+ *  $Id: comandodicomizacionintegracion.cpp 4151 2011-09-14 09:45:58Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -24,6 +24,7 @@
 #include <wx/file.h>
 #include <wx/xml/xml.h>
 #include <wx/mstream.h>
+#include <wx/image.h>
 
 #include <api/globals.h>
 
@@ -152,15 +153,6 @@ namespace GNKVisualizator {
 
 		void ComandoDicomizacionIntegracion::Execute()
 		{
-			wxString codigoLOINC;
-			wxString textoLOINC;
-			wxString strOldPath;
-
-			wxXmlDocument documento;
-
-			listaValoraciones lValoraciones;
-
-			//primero de todo se pega...
 			NotificarProgreso(0.05f, _Std("Step 1 of 3: Importing images"));
 
 			if(!m_pIntegracionParams->m_importacionCorrecta) {
@@ -213,9 +205,9 @@ namespace GNKVisualizator {
 		void ComandoDicomizacionIntegracion::Update()
 		{
 			if(m_pIntegracionParams->m_mensajeError != "") {
-				wxString mensaje = _("Import process failed:\n\t") + wxString::FromUTF8(m_pIntegracionParams->m_mensajeError.c_str()) + _("\nWould you like to retry?");
+				wxString mensaje = _("Import process failed:") + wxString(wxT("\n - ")) + wxString::FromUTF8(m_pIntegracionParams->m_mensajeError.c_str()) + _("\nWould you like to retry?");
 
-				int answer = wxMessageBox(mensaje,_("Info"),wxYES_NO | wxCANCEL | wxICON_INFORMATION, m_pIntegracionParams->m_pEntorno->GetVentanaRaiz());
+				int answer = wxMessageBox(mensaje,_("Info"),wxYES_NO | wxICON_INFORMATION, m_pIntegracionParams->m_pEntorno->GetVentanaRaiz());
 				if(answer == wxYES) {
 					ComandoDicomizacionIntegracionParams* pParams = new ComandoDicomizacionIntegracionParams(*m_pIntegracionParams);
 					ComandoDicomizacionIntegracion* pCmd = new ComandoDicomizacionIntegracion(pParams);
@@ -238,8 +230,84 @@ namespace GNKVisualizator {
 			BorrarArchivosTemporales(FROMPATH(m_pIntegracionParams->m_dirTemporal));
 		}
 
+		//resize files??
+		void ComandoDicomizacionIntegracion::ResizeFiles()
+		{
+			wxString wxDirTemp = FROMPATH(m_pIntegracionParams->m_dirTemporal);
+			int dims[2] = {-1,-1};
+			//dimensiones del mas grande
+			GNC::GCS::Vector vectorMaximo(-1.0,-1.0);
+			GNC::GCS::Vector vectorOrigen(0.0,0.0);
+			//
+			bool redimensionar = false;
+			//se leen las imagenes para ver que tengan la misma dimension
+			for(GNKVisualizator::GUI::TipoWizardImportacion::TListaFicheros::iterator it= m_pIntegracionParams->m_pDatosPersistentes->m_listaFicherosADicomizar.begin(); it!= m_pIntegracionParams->m_pDatosPersistentes->m_listaFicherosADicomizar.end(); it++) {
+				wxString path = FROMPATH(it->pathImagen);
+				wxImage img(path);
+				if(img.Ok())
+				{
+					if(dims[0]==-1 && dims[1]==-1){
+						dims[0]=img.GetWidth();
+						dims[1]=img.GetHeight();
+						vectorMaximo.x =(double) std::max<double>(img.GetWidth(),img.GetHeight());
+						vectorMaximo.y =(double) std::min<double>(img.GetWidth(),img.GetHeight());
+					} else {
+						if(!( (dims[0] == img.GetWidth() && dims[1] == img.GetHeight()) || (dims[1] == img.GetWidth() && dims[0] == img.GetHeight()) )){
+							redimensionar = true;
+							GNC::GCS::Vector v1((double)std::max<double>(img.GetWidth(),img.GetHeight()),(double)std::min<double>(img.GetWidth(),img.GetHeight()));
+							if(!v1.DentroDeBoundingBox(vectorOrigen,vectorMaximo)){
+								vectorMaximo.x = std::max<double>(vectorMaximo.x,v1.x);
+								vectorMaximo.y = std::max<double>(vectorMaximo.y,v1.y);
+							}
+						}
+					}
+				} 
+			}
+
+			//por ultimo si hay que redimensionar se redimensionan proporcionalmente y se rellena con negros
+			if (redimensionar){
+				for(GNKVisualizator::GUI::TipoWizardImportacion::TListaFicheros::iterator it= m_pIntegracionParams->m_pDatosPersistentes->m_listaFicherosADicomizar.begin(); it!= m_pIntegracionParams->m_pDatosPersistentes->m_listaFicherosADicomizar.end(); it++) {
+					wxString pathOrig = FROMPATH(it->pathImagen);
+					wxImage img(pathOrig);
+					if(!( (vectorMaximo.x == img.GetWidth() && vectorMaximo.y == img.GetHeight()) || (vectorMaximo.x == img.GetWidth() && vectorMaximo.y == img.GetHeight()) )){
+						//primero se rescala proporcionalmente
+						double scale;
+						if(img.GetHeight() > img.GetWidth()){
+							scale = (double)vectorMaximo.x / img.GetHeight();
+						} else {
+							scale = (double)vectorMaximo.x / img.GetWidth();
+						}
+						img = img.Rescale(img.GetWidth()*scale,img.GetHeight()*scale,wxIMAGE_QUALITY_HIGH);
+						//se cambia el tamao hasta el maximo
+						if(img.GetHeight() > img.GetWidth()){
+							wxPoint punto((vectorMaximo.y / 2) - ((float)img.GetWidth()/2),0);
+							img = img.Resize(wxSize(vectorMaximo.y,vectorMaximo.x),punto,0,0,0);
+						} else {
+							wxPoint punto(0,(vectorMaximo.y / 2) - ((float)img.GetHeight()/2));
+							img = img.Resize(wxSize(vectorMaximo.x,vectorMaximo.y),punto,0,0,0);
+						}
+
+						wxFileName fileName(pathOrig);
+						wxString nombreImagenTemporal = wxDirTemp + wxFileName::GetPathSeparator() + fileName.GetName() + wxString::Format(wxT("%d"),rand()) + wxT(".jpg");
+						while(wxFile::Exists(nombreImagenTemporal))
+						{
+							//si existe se busca uno que no exista
+							nombreImagenTemporal= wxDirTemp + wxFileName::GetPathSeparator() + fileName.GetName() + wxString::Format(wxT("%d"),rand()) + wxT(".jpg");
+						}
+						img.SetOption(wxIMAGE_OPTION_QUALITY,100);
+						img.SaveFile(nombreImagenTemporal);
+						(*it).pathImagen = TOPATH(nombreImagenTemporal);
+
+					}
+				}
+			}
+		}
+
+
+
 		bool ComandoDicomizacionIntegracion::ImportarFicherosOriginales()
 		{
+			ResizeFiles();
 			bool esElPrimero=true;
 
 			GIL::DICOM::IPACSController* pCI = m_pIntegracionParams->m_pEntorno->GetPACSController();
@@ -333,8 +401,9 @@ namespace GNKVisualizator {
 					}//fin leer tags
 
 				}
-				catch (GIL::DICOM::I2DException& e) {
-					LOG_ERROR("DICOMIZATION", "Error in dicomization process: " << e);
+				catch (GIL::DICOM::I2DException& ex) {
+					m_pIntegracionParams->m_mensajeError = ex.GetCause();
+					LOG_ERROR("DICOMIZATION", "Error in dicomization process: " << ex);
 					if (pI2D != NULL) {						
 						pCI->LiberarInstanciaDeImportacion(pI2D);
 					}
@@ -344,6 +413,7 @@ namespace GNKVisualizator {
 					return false;
 				}				
 				catch (std::exception& e) {
+					m_pIntegracionParams->m_mensajeError = e.what();
 					LOG_ERROR("DICOMIZATION", "Error doing dicomization: " << e.what() );
 					if (pI2D != NULL) {						
 						pCI->LiberarInstanciaDeImportacion(pI2D);
@@ -354,6 +424,7 @@ namespace GNKVisualizator {
 					return false;
 				}
 				catch (...) {
+					m_pIntegracionParams->m_mensajeError = _Std("Unkown error in dicomization process");
 					LOG_ERROR("Internal error in dicomization process", "DICOMIZATION");
 					if (pI2D != NULL) {
 						pCI->LiberarInstanciaDeImportacion(pI2D);
