@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: visualizatorcontroller.cpp 3963 2011-07-11 14:03:51Z tovar $
+ *  $Id: visualizatorcontroller.cpp 4166 2011-09-21 08:05:46Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -96,7 +96,7 @@ GNKVisualizator::ControladorAtencionPrimaria::ControladorAtencionPrimaria(GNC::G
 	m_Version = oversion.str();
 
 	// Codigos LOINC de los informes de A. Primaria.
-	m_ListaInformes.push_back(GNC::GCS::IdHL7("TUID" + m_UID, "0", _Std("Ginkgo CADx visualizator Report"), "LN", "", "","v1.0"));
+	m_ListaInformes.push_back(GNC::GCS::IdHL7("TUID" + m_UID, "0", _Std("Ginkgo CADx Image Report"), "LN", "", "","v1.0"));
 
 
 	// Codigos LOINC de los Estudios que genera A. Primaria
