@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: vista2d.cpp 3834 2011-05-10 07:42:57Z carlos $
+ *  $Id: vista2d.cpp 4122 2011-09-02 12:08:58Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -38,6 +38,7 @@
 #include <export/iherramientamarcado.h>
 #include <export/iherramientarejillametrica.h>
 #include <export/iherramientaanotacionesesquina.h>
+#include <export/iherramientainterpolate.h>
 #include <api/imodelointegracion.h>
 #include <api/icontroladormodulo.h>
 #include <api/icontroladorpermisos.h>
@@ -90,6 +91,7 @@ GNKVisualizator::Vista2D::Vista2D(const GnkPtr<GNKVisualizator::VisualizatorStud
 	GNC::GCS::IHerramientaRejillaMetrica*      hRejilla = NULL;
 	GNC::GCS::IHerramientaReset*               hReset = NULL;
 	GNC::GCS::IHerramientaLayoutVentana*       hHerramientaLayoutVentana = NULL;
+	GNC::GCS::IHerramientaInterpolate*			 hInterpolate = NULL;
 	GNKVisualizator::IHerramientaOverlays*     hOverlays = NULL;
 	GNKVisualizator::IHerramientaMapaColor*    hMapa = NULL;
 
@@ -149,6 +151,12 @@ GNKVisualizator::Vista2D::Vista2D(const GnkPtr<GNKVisualizator::VisualizatorStud
 			hReset->Subscribir(this,GVista);
 		}
 
+		// Subscribimos la vista al contrato de mapas de color
+		hInterpolate = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaInterpolate>(GNC::GCS::IHerramientaInterpolate::ID);
+		if (hInterpolate != NULL) {
+			hInterpolate->Subscribir(this,GVista);
+		}
+
 		// Subscribimos la vista al contrato de tags
 		hHerramientaLayoutVentana = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaLayoutVentana>(GNC::GCS::IHerramientaLayoutVentana::ID);
 		if (hHerramientaLayoutVentana != NULL) {
@@ -190,6 +198,7 @@ GNKVisualizator::Vista2D::~Vista2D()
 	GNC::GCS::IHerramientaMarcado*            hMarcado       = NULL;
 	GNC::GCS::IHerramientaRejillaMetrica*     hRejilla = NULL;
 	GNC::GCS::IHerramientaReset*              hReset = NULL;
+	GNC::GCS::IHerramientaInterpolate*			 hInterpolate = NULL;
 	GNC::GCS::IHerramientaLayoutVentana*      hHerramientaLayoutVentana = NULL;
 	GNKVisualizator::IHerramientaOverlays*          hOverlays = NULL;
 	GNKVisualizator::IHerramientaMapaColor*         hMapa = NULL;
@@ -257,6 +266,12 @@ GNKVisualizator::Vista2D::~Vista2D()
 			hReset->DesSubscribirsLosDeLaVista(this);
 		}
 
+		// Subscribimos la vista al contrato de mapas de color
+		hInterpolate = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaInterpolate>(GNC::GCS::IHerramientaInterpolate::ID);
+		if (hInterpolate != NULL) {
+			hInterpolate->DesSubscribirsLosDeLaVista(this);
+		}
+
 		// dessuscribimos paneltags
 		hHerramientaLayoutVentana = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaLayoutVentana>(GNC::GCS::IHerramientaLayoutVentana::ID);
 		if (hHerramientaLayoutVentana != NULL) {
@@ -407,7 +422,7 @@ void GNKVisualizator::Vista2D::Activar()
 {
 	GNC::GCS::IVista::Activar();
 	VisualizatorStudy->Modulo->OcultarPaneles();
-//#if !defined(_WINDOWS)
+//#if defined(_WINDOWS)
 	GVista->SetFocus();
 //#endif
 }
