@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: gvistacompleja.cpp 3893 2011-06-21 13:01:56Z tovar $
+ *  $Id: gvistacompleja.cpp 4124 2011-09-02 12:21:20Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -17,6 +17,7 @@
 #include "imprimevistasimple.h"
 #include "../vistas/vista2d.h"
 #include "../../recursos/aprimresourcemanager.h"
+#include <resources/ginkgoresourcemanager.h>
 
 #include <wx/msgdlg.h>
 #include <wx/menu.h>
@@ -195,7 +196,7 @@ GVistaCompleja::GVistaCompleja(GNKVisualizator::Vista2D* pIVista) : VistaComplej
 	m_pSizerIzquierda->Add(m_pBarraIzquierda,0, wxALIGN_CENTER_VERTICAL|wxEXPAND,0);
 
 	m_pBarraCine = new BarraHerramientasBotones(m_pPanelManipulacion);
-	m_pBarraCine->AddTool(ID_BOTON_PLAY_STOP,_("Play"),APrimResourcesManager::BarraCine::GetIcoPlay(),_("Play"));
+	m_pBarraCine->AddTool(ID_BOTON_PLAY_STOP,_("Play"),GinkgoResourcesManager::BarraCine::GetIcoPlay(),_("Play"));
 	m_pBarraCine->Connect(ID_BOTON_PLAY_STOP,wxEVT_COMMAND_TOOL_CLICKED, wxCommandEventHandler( GVistaCompleja::OnPlayStopClick),NULL,this);
 	m_pBarraCine->SetToolDropDown(ID_BOTON_PLAY_STOP, true);
 	m_pBarraCine->Connect(ID_BOTON_PLAY_STOP,wxEVT_COMMAND_AUITOOLBAR_TOOL_DROPDOWN, wxAuiToolBarEventHandler( GVistaCompleja::OnMenuCineClick),NULL,this);
@@ -582,9 +583,9 @@ void GVistaCompleja::OnMenuCineClick(wxAuiToolBarEvent& evt)
 
 		wxMenuItem* pItem = new wxMenuItem(&menuVer,wxID_ANY,_("Loop"),_("Repeat on end"),wxITEM_CHECK);
 		#ifdef __WXMSW__
-		pItem->SetBitmaps(APrimResourcesManager::BarraCine::GetIcoBucle(),APrimResourcesManager::BarraCine::GetIcoNoBucle());
+		pItem->SetBitmaps(GinkgoResourcesManager::BarraCine::GetIcoBucle(),GinkgoResourcesManager::BarraCine::GetIcoNoBucle());
 		//#else
-		//pItem->SetBitmap(APrimResourcesManager::BarraCine::GetIcoBucle());
+		//pItem->SetBitmap(GinkgoResourcesManager::BarraCine::GetIcoBucle());
 		#endif
 		//este apend suelta por consola: 'InsertMenuItem()' failed with error 0x00000057, es un buf arreglado pero no afecta negativamente,
 		// es xq solo tiene un bitmap mas info:
@@ -597,18 +598,18 @@ void GVistaCompleja::OnMenuCineClick(wxAuiToolBarEvent& evt)
 		if(!m_playTimer->IsRunning()){
 			pItem = new wxMenuItem(&menuVer,wxID_ANY,_("Play"),_("Start playback"));
 			#ifdef __WXMSW__
-			pItem->SetBitmaps(APrimResourcesManager::BarraCine::GetIcoPlay());
+			pItem->SetBitmaps(GinkgoResourcesManager::BarraCine::GetIcoPlay());
 			#else
-			pItem->SetBitmap(APrimResourcesManager::BarraCine::GetIcoPlay());
+			pItem->SetBitmap(GinkgoResourcesManager::BarraCine::GetIcoPlay());
 			#endif
 			menuVer.Append(pItem);
 			menuVer.Connect(pItem->GetId(),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( GVistaCompleja::OnPlayStopClick ),NULL,this);
 		} else {
 			pItem = new wxMenuItem(&menuVer,wxID_ANY,_("Stop"),_("End playback"));
 			#ifdef __WXMSW__
-			pItem->SetBitmaps(APrimResourcesManager::BarraCine::GetIcoPause());
+			pItem->SetBitmaps(GinkgoResourcesManager::BarraCine::GetIcoPause());
 			#else
-			pItem->SetBitmap(APrimResourcesManager::BarraCine::GetIcoPause());
+			pItem->SetBitmap(GinkgoResourcesManager::BarraCine::GetIcoPause());
 			#endif
 			menuVer.Append(pItem);
 			menuVer.Connect(pItem->GetId(),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( GVistaCompleja::OnPlayStopClick ),NULL,this);
@@ -703,7 +704,7 @@ void GVistaCompleja::ActualizarMaxMinSlider()
 		m_pSliderSlice->SetRange(minSlider, maxSlider);
 		m_pSliderSlice->Enable(true);
 		if( !m_pBarraCine->IsShown() ) {
-			m_pBarraCine->SetToolBitmap(ID_BOTON_PLAY_STOP, APrimResourcesManager::BarraCine::GetIcoPlay());
+			m_pBarraCine->SetToolBitmap(ID_BOTON_PLAY_STOP, GinkgoResourcesManager::BarraCine::GetIcoPlay());
 			m_pBarraCine->SetToolShortHelp(ID_BOTON_PLAY_STOP, _("Play"));
 			m_pBarraCine->Enable(true);
 			m_pBarraCine->Show(true);
@@ -778,6 +779,7 @@ void GVistaCompleja::OnKeyDown( wxKeyEvent& event )
 			}
 			break;
 		default:
+			event.ResumePropagation(1);
 			event.Skip(true);
 	}
 }
@@ -824,7 +826,7 @@ void GVistaCompleja::Play()
 		GoToSlice(0,false);
 	}
 	m_playTimer->Start(m_PeriodoMs);
-	m_pBarraCine->SetToolBitmap(ID_BOTON_PLAY_STOP, APrimResourcesManager::BarraCine::GetIcoStop());
+	m_pBarraCine->SetToolBitmap(ID_BOTON_PLAY_STOP, GinkgoResourcesManager::BarraCine::GetIcoStop());
 	m_pBarraCine->SetToolShortHelp(ID_BOTON_PLAY_STOP, _("Stop"));
 	m_pBarraCine->Refresh();
 
@@ -836,7 +838,7 @@ void GVistaCompleja::Stop()
 {
 	//stop
 	m_playTimer->Stop();
-	m_pBarraCine->SetToolBitmap(ID_BOTON_PLAY_STOP, APrimResourcesManager::BarraCine::GetIcoPlay());
+	m_pBarraCine->SetToolBitmap(ID_BOTON_PLAY_STOP, GinkgoResourcesManager::BarraCine::GetIcoPlay());
 	m_pBarraCine->SetToolShortHelp(ID_BOTON_PLAY_STOP, _("Play"));
 	m_pBarraCine->Refresh();
 
